/** @packageDocumentation
 * @module Utilities
 */
/** Import color themes, layout variables and Sass classes barrel file */
import "./colorthemes.scss";
import "./layout-variables.scss";
import "./classes.scss";
import { I18N } from "@bentley/imodeljs-i18n";
/**
 * Manages the I18N service for the ui-core package.
 * @public
 */
export declare class UiCore {
    private static _initialized;
    private static _i18n?;
    /**
     * Registers the I18N service namespace for UiCore. Also initializes UiAbstract.
     * @param i18n The internationalization service created by the application.
     */
    static initialize(i18n: I18N): Promise<void>;
    /** Unregisters the UiCore I18N namespace */
    static terminate(): void;
    /** Determines if UiCore has been initialized */
    static get initialized(): boolean;
    /** The internationalization service created by the application. */
    static get i18n(): I18N;
    /** The internationalization service namespace. */
    static get i18nNamespace(): string;
    /** Calls i18n.translateWithNamespace with the "UiCore" namespace. Do NOT include the namespace in the key.
     * @internal
     */
    static translate(key: string | string[]): string;
    /** @internal */
    static get packageName(): string;
    /** @internal */
    static loggerCategory(obj: any): string;
}
//# sourceMappingURL=UiCore.d.ts.map