/** @packageDocumentation
 * @module Button
 */
import * as React from "react";
import { CommonProps } from "../utils/Props";
/** Sizes for [[Button]] component
 * @public
 */
export declare enum ButtonSize {
    Default = "",
    Large = "large"
}
/** Types for [[Button]] component
 * @public
 */
export declare enum ButtonType {
    Primary = "primary",
    Blue = "blue",
    Disabled = "disabled",
    Hollow = "hollow"
}
/** Properties for [[Button]] component
 * @public
 */
export interface ButtonProps extends React.ButtonHTMLAttributes<HTMLButtonElement>, CommonProps {
    /** Allow ID to be passed to Button */
    id?: string;
    /** Default and large sizes */
    size?: ButtonSize;
    /** 4 styles to tweak the content of the button */
    buttonType?: ButtonType;
    /** A function to be run when the element is clicked */
    onClick?: ((event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void);
}
/** Generic button component
 * @public
 */
export declare class Button extends React.PureComponent<ButtonProps> {
    render(): JSX.Element;
}
/** @internal */
export declare function getButtonTypeClassName(buttonType?: ButtonType): string;
//# sourceMappingURL=Button.d.ts.map