"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Button
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getButtonTypeClassName = exports.Button = exports.ButtonType = exports.ButtonSize = void 0;
const classnames = require("classnames");
const React = require("react");
/** Sizes for [[Button]] component
 * @public
 */
var ButtonSize;
(function (ButtonSize) {
    ButtonSize["Default"] = "";
    ButtonSize["Large"] = "large";
})(ButtonSize = exports.ButtonSize || (exports.ButtonSize = {}));
/** Types for [[Button]] component
 * @public
 */
var ButtonType;
(function (ButtonType) {
    ButtonType["Primary"] = "primary";
    ButtonType["Blue"] = "blue";
    ButtonType["Disabled"] = "disabled";
    ButtonType["Hollow"] = "hollow";
})(ButtonType = exports.ButtonType || (exports.ButtonType = {}));
/** Generic button component
 * @public
 */
class Button extends React.PureComponent {
    render() {
        const _a = this.props, { buttonType, size, className, style, onClick } = _a, props = __rest(_a, ["buttonType", "size", "className", "style", "onClick"]);
        let typeClassName = getButtonTypeClassName(buttonType);
        if (size === ButtonSize.Large)
            typeClassName += "-large";
        return React.createElement("button", Object.assign({}, props, { className: classnames(typeClassName, className), style: style, onClick: onClick }));
    }
}
exports.Button = Button;
/** @internal */
function getButtonTypeClassName(buttonType) {
    let typeClassName;
    switch (buttonType) {
        case ButtonType.Blue:
            typeClassName = "uicore-buttons-blue";
            break;
        case ButtonType.Disabled:
            typeClassName = "uicore-buttons-disabled";
            break;
        case ButtonType.Hollow:
            typeClassName = "uicore-buttons-hollow";
            break;
        case ButtonType.Primary:
        default:
            typeClassName = "uicore-buttons-primary";
            break;
    }
    return typeClassName;
}
exports.getButtonTypeClassName = getButtonTypeClassName;
//# sourceMappingURL=Button.js.map