"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Button
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.UnderlinedButton = void 0;
require("./UnderlinedButton.scss");
const classnames = require("classnames");
const React = require("react");
const ui_abstract_1 = require("@bentley/ui-abstract");
/** A React component that makes text clickable and underlined
 * @public
 */
function UnderlinedButton(props) {
    const handleKeyUp = React.useCallback((event) => {
        const key = event.key;
        switch (key) {
            case ui_abstract_1.SpecialKey.Enter:
            case ui_abstract_1.SpecialKey.Space:
                props.onActivate && props.onActivate();
                break;
        }
    }, [props]);
    const handleClick = React.useCallback((e) => {
        props.onClick && props.onClick(e);
        props.onActivate && props.onActivate();
    }, [props]);
    const className = classnames("core-underlined-button", props.className ? props.className : undefined);
    return (React.createElement("span", { className: className, title: props.title, onClick: handleClick, onKeyUp: handleKeyUp, tabIndex: 0, role: "link" }, props.children));
}
exports.UnderlinedButton = UnderlinedButton;
//# sourceMappingURL=UnderlinedButton.js.map