/** @packageDocumentation
 * @module Checkbox
 */
import * as React from "react";
import { InputStatus } from "../inputs/InputStatus";
import { CommonProps } from "../utils/Props";
import { Omit } from "../utils/typeUtils";
/** Properties for [[Checkbox]] React component
 * @public
 */
export interface CheckboxProps extends Omit<React.InputHTMLAttributes<HTMLInputElement>, "type" | "onClick" | "onBlur">, CommonProps {
    /** Text that will be shown next to the checkbox. */
    label?: string;
    /** Indicates checkbox is in an Indeterminate or Partial state, regardless of the `checked` state */
    indeterminate?: boolean;
    /** Input status like: "Success", "Warning" or "Error" */
    status?: InputStatus;
    /** Custom CSS class name for the checkbox input element */
    inputClassName?: string;
    /** Custom CSS Style for the checkbox input element */
    inputStyle?: React.CSSProperties;
    /** Custom CSS class name for the label element */
    labelClassName?: string;
    /** Custom CSS Style for the label element */
    labelStyle?: React.CSSProperties;
    /**
     * Event called when checkbox is clicked on. This is a good event to
     * use for preventing the action from bubbling to component's parents.
     */
    onClick?: (e: React.MouseEvent) => void;
    /** Event called when checkbox loses focus. */
    onBlur?: (e: React.FocusEvent) => void;
    /** Indicates whether the checkbox should set focus */
    setFocus?: boolean;
    /** Provides ability to return reference to HTMLInputElement */
    inputRef?: React.Ref<HTMLInputElement>;
}
/** A React component that renders a simple checkbox with label.
 * It is a wrapper for the `<input type="checkbox">` HTML element.
 * @public
 */
export declare class Checkbox extends React.PureComponent<CheckboxProps> {
    private _checkboxInput;
    private _refs;
    /** @internal */
    constructor(props: CheckboxProps);
    private _onCheckboxClick;
    private _onCheckboxBlur;
    private _setIndeterminate;
    componentDidMount(): void;
    /** @internal */
    componentDidUpdate(_prevProps: CheckboxProps): void;
    render(): JSX.Element;
}
//# sourceMappingURL=Checkbox.d.ts.map