"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Checkbox
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Checkbox = void 0;
const classnames = require("classnames");
const React = require("react");
const useRefs_1 = require("../utils/hooks/useRefs");
/** A React component that renders a simple checkbox with label.
 * It is a wrapper for the `<input type="checkbox">` HTML element.
 * @public
 */
class Checkbox extends React.PureComponent {
    /** @internal */
    constructor(props) {
        super(props);
        this._checkboxInput = React.createRef();
        this._refs = useRefs_1.mergeRefs(this._checkboxInput);
        this._onCheckboxClick = (e) => {
            e.stopPropagation();
        };
        this._onCheckboxBlur = (e) => {
            e.stopPropagation();
        };
        if (props.inputRef)
            this._refs = useRefs_1.mergeRefs(this._checkboxInput, props.inputRef);
    }
    _setIndeterminate(indeterminate) {
        // istanbul ignore else
        if (this._checkboxInput.current)
            this._checkboxInput.current.indeterminate = indeterminate;
    }
    componentDidMount() {
        if (this.props.indeterminate !== undefined)
            this._setIndeterminate(this.props.indeterminate);
        if (this.props.setFocus && this._checkboxInput.current)
            this._checkboxInput.current.focus();
    }
    /** @internal */
    componentDidUpdate(_prevProps) {
        if (this.props.indeterminate !== undefined)
            this._setIndeterminate(this.props.indeterminate);
    }
    render() {
        const _a = this.props, { status, disabled, label, indeterminate, className, inputClassName, inputStyle, labelClassName, labelStyle, // eslint-disable-line @typescript-eslint/no-unused-vars
        onClick, onBlur, setFocus, inputRef } = _a, inputProps = __rest(_a, ["status", "disabled", "label", "indeterminate", "className", "inputClassName", "inputStyle", "labelClassName", "labelStyle", "onClick", "onBlur", "setFocus", "inputRef"]); // eslint-disable-line @typescript-eslint/no-unused-vars
        const checkBoxClass = classnames("core-checkbox", disabled && "core-disabled", !label && "core-checkbox-no-label", status, className);
        return (
        /* eslint-disable jsx-a11y/no-noninteractive-element-interactions */
        /* eslint-disable-next-line jsx-a11y/click-events-have-key-events */
        React.createElement("label", { className: checkBoxClass, onClick: onClick, onBlur: onBlur },
            label &&
                React.createElement("span", { className: "core-checkbox-label" }, label),
            React.createElement("input", Object.assign({ type: "checkbox", ref: this._refs }, inputProps, { disabled: disabled, className: inputClassName, style: inputStyle, onClick: this._onCheckboxClick, onBlur: this._onCheckboxBlur })),
            React.createElement("span", { className: "core-checkbox-checkmark" })));
    }
}
exports.Checkbox = Checkbox;
//# sourceMappingURL=Checkbox.js.map