"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module CheckListBox
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.CheckListBox = exports.CheckListBoxSeparator = exports.CheckListBoxItem = void 0;
require("./CheckListBox.scss");
const classnames = require("classnames");
const React = require("react");
const Checkbox_1 = require("../checkbox/Checkbox");
/** Item with a checkbox added to a [[CheckListBox]].
 * @public
 */
class CheckListBoxItem extends React.PureComponent {
    render() {
        const className = classnames("core-chk-listboxitem-checkbox", this.props.className);
        return (React.createElement("li", null,
            React.createElement(Checkbox_1.Checkbox, { checked: this.props.checked, disabled: this.props.disabled, inputClassName: className, style: this.props.style, label: this.props.label, onClick: this.props.onClick, onChange: this.props.onChange, "data-testid": "core-chk-listboxitem-checkbox" })));
    }
}
exports.CheckListBoxItem = CheckListBoxItem;
/** Separator added to a [[CheckListBox]].
 * @public
 */
function CheckListBoxSeparator() {
    return (React.createElement("div", { className: "core-chk-listbox-separator" }));
}
exports.CheckListBoxSeparator = CheckListBoxSeparator;
/** React component showing a list of Checkbox items.
 * @public
 */
class CheckListBox extends React.PureComponent {
    render() {
        const className = classnames("core-chk-listbox", this.props.className);
        return (React.createElement("ul", { className: className, style: this.props.style }, this.props.children));
    }
}
exports.CheckListBox = CheckListBox;
//# sourceMappingURL=CheckListBox.js.map