/** @packageDocumentation
 * @module ContextMenu
 */
import * as React from "react";
import { BadgeType, ConditionalBooleanValue } from "@bentley/ui-abstract";
import { CommonProps } from "../utils/Props";
import { ContextMenu } from "./ContextMenu";
import { IconSpec } from "../icons/IconComponent";
/** Properties for the [[ContextMenuItem]] component
 * @public
 */
export interface ContextMenuItemProps extends Omit<React.AllHTMLAttributes<HTMLDivElement>, "disabled" | "hidden">, CommonProps {
    onSelect?: (event: any) => any;
    /** @internal */
    onHotKeyParsed?: (hotKey: string) => void;
    /** Icon to display in the left margin. */
    icon?: IconSpec;
    /** Disables any onSelect calls, hover/keyboard highlighting, and grays item. */
    disabled?: boolean | ConditionalBooleanValue;
    /** Indicates whether the item is visible or hidden. The default is for the item to be visible. */
    hidden?: boolean | ConditionalBooleanValue;
    /** Badge to be overlaid on the item. */
    badgeType?: BadgeType;
    /** Icon to display in the right margin. */
    iconRight?: IconSpec;
    /** Hide the icon container. This can be used to eliminate space used to display an icon at the left of the menu item. */
    hideIconContainer?: boolean;
    /** @internal */
    onHover?: () => any;
    isSelected?: boolean;
    /** @internal */
    parentMenu?: ContextMenu;
}
/** @internal */
interface ContextMenuItemState {
    hotKey?: string;
}
/**
 * Menu Item class for use within a [[ContextMenu]] component.
 * @public
 */
export declare class ContextMenuItem extends React.PureComponent<ContextMenuItemProps, ContextMenuItemState> {
    private _root;
    private _lastChildren;
    private _parsedChildren;
    /** @internal */
    static defaultProps: Partial<ContextMenuItemProps>;
    constructor(props: ContextMenuItemProps);
    /** @internal */
    readonly state: Readonly<ContextMenuItemState>;
    render(): JSX.Element;
    componentDidMount(): void;
    componentDidUpdate(prevProps: ContextMenuItemProps): void;
    private _updateHotkey;
    private _handleFocus;
    private _handleMouseOver;
    select: () => void;
    private _handleClick;
    private _handleKeyUp;
}
export {};
//# sourceMappingURL=ContextMenuItem.d.ts.map