/** @packageDocumentation
 * @module ContextMenu
 */
import * as React from "react";
import { ContextMenuItemProps } from "./ContextMenuItem";
import { ContextMenuProps } from "./ContextMenu";
import { CommonProps } from "../utils/Props";
import { ContextMenuDirection } from "./ContextMenuDirection";
/** Properties for the [[ContextSubMenu]] component
 * @public
 */
export interface ContextSubMenuProps extends Omit<ContextMenuItemProps, "label">, Omit<ContextMenuProps, "label">, CommonProps {
    /** Text/jsx to display in the list item */
    label: string | JSX.Element;
    /** @internal */
    onHotKeyParsed?: (hotKey: string) => void;
}
/** @internal */
interface ContextSubMenuState {
    opened: boolean;
    direction: ContextMenuDirection;
    hotKey?: string;
}
/**
 * Submenu wrapper class for use within a [[ContextMenu]] component.
 * @public
 */
export declare class ContextSubMenu extends React.Component<ContextSubMenuProps, ContextSubMenuState> {
    private _menuElement;
    private _subMenuElement;
    private _menuButtonElement;
    private _lastLabel;
    private _parsedLabel;
    static defaultProps: Partial<ContextSubMenuProps>;
    /** @internal */
    readonly state: Readonly<ContextSubMenuState>;
    constructor(props: ContextSubMenuProps);
    render(): JSX.Element;
    componentDidMount(): void;
    componentWillUnmount(): void;
    componentDidUpdate(prevProps: ContextSubMenuProps, prevState: ContextSubMenuState): void;
    private getWindow;
    private checkRenderDirection;
    private _updateHotkey;
    select: () => void;
    close: (propagate?: boolean | undefined) => void;
    private _handleMouseOver;
    private _handleClick;
    private _handleClickGlobal;
}
export {};
//# sourceMappingURL=ContextSubMenu.d.ts.map