"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module ContextMenu
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContextSubMenu = void 0;
const React = require("react");
const classnames = require("classnames");
const ui_abstract_1 = require("@bentley/ui-abstract");
const ContextMenu_1 = require("./ContextMenu");
const ContextMenuDirection_1 = require("./ContextMenuDirection");
const TildeFinder_1 = require("./TildeFinder");
const BadgeUtilities_1 = require("../badge/BadgeUtilities");
/**
 * Submenu wrapper class for use within a [[ContextMenu]] component.
 * @public
 */
class ContextSubMenu extends React.Component {
    constructor(props) {
        super(props);
        this._menuElement = null;
        this._subMenuElement = null;
        this._menuButtonElement = null;
        this._updateHotkey = (node) => {
            let hotKey;
            const isDisabled = ui_abstract_1.ConditionalBooleanValue.getValue(this.props.disabled);
            const isHidden = ui_abstract_1.ConditionalBooleanValue.getValue(this.props.hidden);
            if (!isDisabled && !isHidden)
                hotKey = TildeFinder_1.TildeFinder.findAfterTilde(node).character;
            else
                hotKey = undefined;
            if (hotKey && hotKey !== this.state.hotKey) {
                this.setState({ hotKey });
                if (this.props.onHotKeyParsed)
                    this.props.onHotKeyParsed(hotKey);
            }
        };
        this.select = () => {
            this.setState({ opened: true }, () => {
                // istanbul ignore else
                if (this._menuElement)
                    this._menuElement.focus();
                if (this.props.onSelect !== undefined)
                    this.props.onSelect(undefined);
            });
        };
        this.close = (propagate) => {
            this.setState({ opened: false }, () => {
                // istanbul ignore else
                if (this._menuElement)
                    this._menuElement.blur();
            });
            // istanbul ignore next
            if (propagate && this.props.parentMenu && this.props.parentMenu.props.parentSubmenu) {
                this.props.parentMenu.props.parentSubmenu.close(true);
            }
        };
        this._handleMouseOver = (_event) => {
            // istanbul ignore else
            if (this._menuButtonElement && this._menuButtonElement.style.visibility !== "hidden" && this.props.onHover) {
                this.props.onHover();
            }
        };
        this._handleClick = (event) => {
            event.stopPropagation();
            const isDisabled = ui_abstract_1.ConditionalBooleanValue.getValue(this.props.disabled);
            // istanbul ignore else
            if (!isDisabled) {
                // istanbul ignore else
                if (this.props.onClick !== undefined)
                    this.props.onClick(event);
                // istanbul ignore next
                if (this.props.opened)
                    this.close();
                else
                    this.select();
            }
        };
        this._handleClickGlobal = (event) => {
            if (this._subMenuElement && !this._subMenuElement.contains(event.target))
                this.setState((_prevState) => ({ opened: false }));
        };
        this.state = {
            opened: false,
            direction: props.direction,
        };
    }
    render() {
        const _a = this.props, { label, opened, direction, onOutsideClick, onEsc, autoflip, edgeLimit, selectedIndex, floating, parentMenu, parentSubmenu, // eslint-disable-line @typescript-eslint/no-unused-vars
        onSelect, icon, disabled, hidden, onHover, isSelected, onHotKeyParsed, // eslint-disable-line @typescript-eslint/no-unused-vars
        children, onClick, className, badgeType } = _a, props = __rest(_a, ["label", "opened", "direction", "onOutsideClick", "onEsc", "autoflip", "edgeLimit", "selectedIndex", "floating", "parentMenu", "parentSubmenu", "onSelect", "icon", "disabled", "hidden", "onHover", "isSelected", "onHotKeyParsed", "children", "onClick", "className", "badgeType"]); // eslint-disable-line @typescript-eslint/no-unused-vars
        const contextMenuProps = { onOutsideClick, onSelect, onEsc, autoflip, edgeLimit, selectedIndex, floating, parentMenu };
        const badge = BadgeUtilities_1.BadgeUtilities.getComponentForBadgeType(badgeType);
        const renderDirection = this.state.direction;
        const isDisabled = ui_abstract_1.ConditionalBooleanValue.getValue(disabled);
        const isHidden = ui_abstract_1.ConditionalBooleanValue.getValue(hidden);
        if (this._lastLabel !== label) {
            this._parsedLabel = TildeFinder_1.TildeFinder.findAfterTilde(label).node;
            this._lastLabel = label;
        }
        return (
        // eslint-disable-next-line jsx-a11y/mouse-events-have-key-events
        React.createElement("div", Object.assign({ className: classnames("core-context-submenu", ContextMenu_1.ContextMenu.getCSSClassNameFromDirection(renderDirection), className), onMouseOver: this._handleMouseOver, ref: (el) => { this._subMenuElement = el; }, "data-testid": "core-context-submenu" }, props),
            React.createElement("div", { onClick: this._handleClick, ref: (el) => { this._menuButtonElement = el; }, className: classnames("core-context-menu-item", "core-context-submenu-container", isDisabled && "core-context-menu-disabled", isHidden && "core-context-menu-hidden", isSelected && "core-context-menu-is-selected"), "data-testid": "core-context-submenu-container", role: "menuitem", tabIndex: isSelected ? 0 : -1, "aria-disabled": isDisabled, "aria-hidden": isHidden, "aria-haspopup": true },
                React.createElement("div", { className: classnames("core-context-menu-icon", "icon", icon instanceof ui_abstract_1.ConditionalStringValue && /* istanbul ignore next */ icon.value, typeof icon === "string" && /* istanbul ignore next */ icon) }),
                React.createElement("div", { className: "core-context-menu-content" }, this._parsedLabel),
                React.createElement("div", { className: classnames("core-context-submenu-arrow", "icon", "icon-caret-right") }),
                badge &&
                    React.createElement("div", { className: "core-context-menu-badge" }, badge)),
            React.createElement(ContextMenu_1.ContextMenu, Object.assign({ ref: (el) => { this._menuElement = el; }, className: "core-context-submenu-popup", opened: this.state.opened, selectedIndex: 0, direction: renderDirection, parentSubmenu: this }, contextMenuProps), children)));
    }
    componentDidMount() {
        document.addEventListener("click", this._handleClickGlobal);
        this._updateHotkey(this.props.label);
        this.checkRenderDirection();
    }
    componentWillUnmount() {
        document.removeEventListener("click", this._handleClickGlobal);
    }
    componentDidUpdate(prevProps, prevState) {
        const direction = this.props.direction;
        if ((this.state.opened !== prevState.opened && direction !== this.state.direction) || prevProps.direction !== direction)
            this.checkRenderDirection();
        if (this.props.label !== prevProps.label) {
            this._updateHotkey(this.props.label);
        }
    }
    getWindow() {
        const el = this._subMenuElement;
        const parentDocument = el.ownerDocument;
        return parentDocument.defaultView;
    }
    checkRenderDirection() {
        const { autoflip } = this.props;
        const parentWindow = this.getWindow();
        let renderDirection = this.state.direction;
        // istanbul ignore else
        if (parentWindow && autoflip && this._menuElement) {
            const menuRect = this._menuElement.getRect();
            renderDirection = ContextMenu_1.ContextMenu.autoFlip(renderDirection, menuRect, parentWindow.innerWidth, parentWindow.innerHeight);
            // istanbul ignore next
            if (renderDirection !== this.state.direction)
                this.setState({ direction: renderDirection });
        }
    }
}
exports.ContextSubMenu = ContextSubMenu;
ContextSubMenu.defaultProps = {
    direction: ContextMenuDirection_1.ContextMenuDirection.BottomRight,
    disabled: false,
    hidden: false,
    autoflip: true,
    isSelected: false,
    selectedIndex: 0,
};
//# sourceMappingURL=ContextSubMenu.js.map