/** @packageDocumentation
 * @module ContextMenu
 */
import * as React from "react";
import { ContextMenuProps } from "./ContextMenu";
/** Properties for the [[GlobalContextMenu]] component
 * @public
 */
export interface GlobalContextMenuProps extends ContextMenuProps {
    /** Unique identifier, to distinguish from other GlobalContextMenu components. Needed only if multiple GlobalContextMenus are used simultaneously. */
    identifier?: string;
    /** Specifies the x/horizontal position on the viewport. */
    x: number | string;
    /** Specifies the y/vertical position on the viewport. */
    y: number | string;
    /** Context menu element. Default: ContextMenu */
    contextMenuComponent?: React.ComponentType<ContextMenuProps>;
}
/** @internal */
interface GlobalContextMenuState {
    parentDocument: Document | null;
}
/** GlobalContextMenu React component used to display a [[ContextMenu]] at the cursor
 * @public
 */
export declare class GlobalContextMenu extends React.PureComponent<GlobalContextMenuProps, GlobalContextMenuState> {
    private _container?;
    readonly state: GlobalContextMenuState;
    constructor(props: GlobalContextMenuProps);
    componentWillUnmount(): void;
    private _handleRefSet;
    render(): React.ReactNode;
}
export {};
//# sourceMappingURL=GlobalContextMenu.d.ts.map