"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module ContextMenu
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GlobalContextMenu = void 0;
const React = require("react");
const ReactDOM = require("react-dom");
const ContextMenu_1 = require("./ContextMenu");
/** GlobalContextMenu React component used to display a [[ContextMenu]] at the cursor
 * @public
 */
class GlobalContextMenu extends React.PureComponent {
    constructor(props) {
        super(props);
        this.state = {
            parentDocument: null,
        };
        this._handleRefSet = (popupDiv) => {
            var _a;
            const parentDocument = (_a = popupDiv === null || popupDiv === void 0 ? void 0 : popupDiv.ownerDocument) !== null && _a !== void 0 ? _a : null;
            if (parentDocument) {
                this._container = parentDocument.createElement("div");
                this._container.id = this.props.identifier !== undefined ? `dialog-${this.props.identifier}` : "core-global-context-menu";
                let rt = parentDocument.getElementById("core-global-context-menu-root");
                if (!rt) {
                    rt = parentDocument.createElement("div");
                    rt.id = "core-global-context-menu-root";
                    parentDocument.body.appendChild(rt);
                }
                rt.appendChild(this._container);
                // used to support component rendering in pop-out window
                this.setState({ parentDocument });
            }
        };
    }
    componentWillUnmount() {
        // istanbul ignore else
        if (this._container && this._container.parentElement) { // cleanup
            this._container.parentElement.removeChild(this._container);
        }
    }
    render() {
        const _a = this.props, { x, y, identifier, contextMenuComponent } = _a, props = __rest(_a, ["x", "y", "identifier", "contextMenuComponent"]); // eslint-disable-line @typescript-eslint/no-unused-vars
        const positioningStyle = {
            left: x,
            top: y,
        };
        const CtxMenu = contextMenuComponent || ContextMenu_1.ContextMenu; // eslint-disable-line @typescript-eslint/naming-convention
        return (React.createElement("div", { ref: this._handleRefSet, style: { display: "none" } }, this.state.parentDocument &&
            ReactDOM.createPortal(React.createElement("div", { className: "core-context-menu-global", style: positioningStyle },
                React.createElement(CtxMenu, Object.assign({}, props))), this.state.parentDocument.body)));
    }
}
exports.GlobalContextMenu = GlobalContextMenu;
//# sourceMappingURL=GlobalContextMenu.js.map