"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module ContextMenu
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PopupContextMenu = void 0;
const React = require("react");
const Popup_1 = require("../popup/Popup");
const ContextMenu_1 = require("./ContextMenu");
const ui_abstract_1 = require("@bentley/ui-abstract");
const ContextMenuDirection_1 = require("./ContextMenuDirection");
/** Component that displays a ContextMenu within a Popup component, allowing the target element to be specified.
 * @beta
 */
function PopupContextMenu(props) {
    const { style, onSelect, onEsc, autoflip, edgeLimit, hotkeySelect, selectedIndex, children } = props, popupProps = __rest(props, ["style", "onSelect", "onEsc", "autoflip", "edgeLimit", "hotkeySelect", "selectedIndex", "children"]);
    const menuDirection = getContextMenuDirectionFromRelativePosition(popupProps.position);
    return (React.createElement(Popup_1.Popup, Object.assign({}, popupProps, { showShadow: false, showArrow: false, moveFocus: true, style: Object.assign(Object.assign({}, style), { border: "none" }) }),
        React.createElement(ContextMenu_1.ContextMenu, { opened: true, onSelect: onSelect, onEsc: onEsc, autoflip: autoflip, edgeLimit: edgeLimit, hotkeySelect: hotkeySelect, selectedIndex: selectedIndex, direction: menuDirection }, children)));
}
exports.PopupContextMenu = PopupContextMenu;
function getContextMenuDirectionFromRelativePosition(relativePosition) {
    let menuDirection = ContextMenuDirection_1.ContextMenuDirection.Bottom;
    switch (relativePosition) {
        case ui_abstract_1.RelativePosition.Top:
            menuDirection = ContextMenuDirection_1.ContextMenuDirection.Top;
            break;
        case ui_abstract_1.RelativePosition.TopLeft:
            menuDirection = ContextMenuDirection_1.ContextMenuDirection.TopRight;
            break;
        case ui_abstract_1.RelativePosition.TopRight:
            menuDirection = ContextMenuDirection_1.ContextMenuDirection.TopLeft;
            break;
        case ui_abstract_1.RelativePosition.Left:
            menuDirection = ContextMenuDirection_1.ContextMenuDirection.Left;
            break;
        case ui_abstract_1.RelativePosition.Right:
            menuDirection = ContextMenuDirection_1.ContextMenuDirection.Right;
            break;
        case ui_abstract_1.RelativePosition.Bottom:
            menuDirection = ContextMenuDirection_1.ContextMenuDirection.Bottom;
            break;
        case ui_abstract_1.RelativePosition.BottomLeft:
            menuDirection = ContextMenuDirection_1.ContextMenuDirection.BottomRight;
            break;
        case ui_abstract_1.RelativePosition.BottomRight:
            menuDirection = ContextMenuDirection_1.ContextMenuDirection.BottomLeft;
            break;
    }
    return menuDirection;
}
//# sourceMappingURL=PopupContextMenu.js.map