/** @packageDocumentation
 * @module ElementSeparator
 */
import "./ElementSeparator.scss";
import { Orientation } from "../enums/Orientation";
import { CommonProps } from "../utils/Props";
/**
 * Results returned by onRatioChanged callback for determining new ratio and whether the ratio was updated.
 * @public
 */
export interface RatioChangeResult {
    ratio: number;
}
/** Properties of [[ElementSeparator]] React component
 * @public
 */
export interface ElementSeparatorProps extends CommonProps {
    /** Separator orientation */
    orientation: Orientation;
    /** Ratio between left cell and right cell */
    ratio: number;
    /** Area width or height (depending on orientation) in pixels */
    movableArea?: number;
    /** Separator width or height in pixels. 30 by default */
    separatorSize?: number;
    /** Callback to ratio changed event */
    onRatioChanged?: (ratio: number) => void | RatioChangeResult;
    /** Is resize handle hovered */
    isResizeHandleHovered?: boolean;
    /** Callback to hover event change */
    onResizeHandleHoverChanged?: (isHovered: boolean) => void;
    /** Is resize handle being dragged */
    isResizeHandleBeingDragged?: boolean;
    /** Callback to drag event change */
    onResizeHandleDragChanged?: (isDragStarted: boolean) => void;
}
/** A movable button, which allows to change the ratio between left element and right element
 * @public
 */
export declare const ElementSeparator: (props: ElementSeparatorProps) => JSX.Element;
//# sourceMappingURL=ElementSeparator.d.ts.map