"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Expandable
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExpandableBlock = void 0;
require("./ExpandableBlock.scss");
const classnames = require("classnames");
const React = require("react");
/** ExpandableBlock React component is a container that shows and hides child content.
 * @public
 */
class ExpandableBlock extends React.PureComponent {
    render() {
        var _a;
        const cName = classnames("uicore-expandable-blocks-block", this.props.caption && "with-caption", this.props.isExpanded ? "is-expanded" : "is-collapsed", this.props.className);
        const ariaExpanded = this.props.isExpanded ? "true" : "false";
        const tabIndex = (this.props.onKeyPress || this.props.onKeyDown) ? 0 : undefined;
        const title = (_a = this.props.tooltip) !== null && _a !== void 0 ? _a : (typeof this.props.title == "string" ? this.props.title : undefined);
        return (React.createElement("div", { className: cName, style: this.props.style },
            React.createElement("div", { role: "button", "aria-expanded": ariaExpanded, className: "header", onClick: this.props.onClick, onKeyPress: this.props.onKeyPress, onKeyDown: this.props.onKeyDown, tabIndex: tabIndex },
                React.createElement("div", { className: "icon-container" },
                    React.createElement("i", { className: "icon icon-chevron-right" })),
                this.props.caption &&
                    React.createElement("div", { className: "caption", title: this.props.caption }, this.props.caption),
                React.createElement("div", { className: "title", title: title }, this.props.title)),
            React.createElement("div", { className: "content" }, this.props.isExpanded && this.props.children)));
    }
}
exports.ExpandableBlock = ExpandableBlock;
//# sourceMappingURL=ExpandableBlock.js.map