"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Expandable
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExpandableList = void 0;
require("./ExpandableList.scss");
const classnames = require("classnames");
const React = require("react");
/**
 * ExpandableList React component is a container for ExpandableBlock components.
 * @public
 */
class ExpandableList extends React.PureComponent {
    constructor(props) {
        super(props);
        // set active block
        this._handleBlockClick = (index, onClick) => {
            let activeBlock = index;
            if (this.props.singleIsCollapsible && index === this.state.activeBlock)
                activeBlock = -1;
            this.setState({ activeBlock });
            // istanbul ignore else
            if (onClick) {
                onClick(); // fire the ExpandableBlock onClick
            }
        };
        this.state = { activeBlock: this.props.defaultActiveBlock };
    }
    renderBlocks() {
        return React.Children.map(this.props.children, (child, i) => {
            return React.cloneElement(child, {
                key: i,
                isExpanded: (this.props.singleExpandOnly) ? i === this.state.activeBlock : child.props.isExpanded,
                onClick: this._handleBlockClick.bind(this, i, child.props.onClick),
            });
        });
    }
    /** @internal */
    componentDidUpdate(prevProps) {
        if (this.props.defaultActiveBlock !== prevProps.defaultActiveBlock && this.props.defaultActiveBlock !== this.state.activeBlock) {
            this.setState((_, props) => ({ activeBlock: props.defaultActiveBlock }));
        }
    }
    render() {
        return (React.createElement("div", { className: classnames("uicore-expandable-blocks-list", this.props.className), style: this.props.style }, this.renderBlocks()));
    }
}
exports.ExpandableList = ExpandableList;
ExpandableList.defaultProps = {
    singleExpandOnly: false,
    defaultActiveBlock: 0,
};
//# sourceMappingURL=ExpandableList.js.map