"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Form
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Field = void 0;
const React = require("react");
const Checkbox_1 = require("../checkbox/Checkbox");
const Input_1 = require("../inputs/Input");
const Textarea_1 = require("../inputs/Textarea");
const Select_1 = require("../select/Select");
const Form_1 = require("./Form");
/** Component that represents a single field in an input form. Only four type of editors are supported. Field gets/sets state data from/to the context control by the form.
 * @beta
 */
class Field extends React.Component {
    constructor(props) {
        super(props);
    }
    render() {
        return (React.createElement(Form_1.FormContext.Consumer, null, (context) => (React.createElement("div", { className: "core-form-group" },
            this.props.editor.toLowerCase() !== "checkbox" && this.props.label && React.createElement("label", { className: "core-form-label", htmlFor: this.props.id }, this.props.label),
            this.props.editor.toLowerCase() === "textbox" && (React.createElement(Input_1.Input, { id: this.props.id, value: context.values[this.props.id], onChange: (event) => context.setValues({ [this.props.id]: event.currentTarget.value }), className: "core-form-input" })),
            this.props.editor.toLowerCase() === "checkbox" && (React.createElement(Checkbox_1.Checkbox, { label: this.props.label, id: this.props.id, checked: context.values[this.props.id], onChange: () => context.setValues({ [this.props.id]: !context.values[this.props.id] }) })),
            this.props.editor.toLowerCase() === "multilinetextbox" && (React.createElement(Textarea_1.Textarea, { id: this.props.id, value: context.values[this.props.id], onChange: (event) => context.setValues({ [this.props.id]: event.currentTarget.value }), className: "core-form-textarea" })),
            this.props.editor.toLowerCase() === "dropdown" && this.props.options && (React.createElement(Select_1.Select, { id: this.props.id, name: this.props.id, value: context.values[this.props.id], onChange: (event) => context.setValues({ [this.props.id]: event.currentTarget.value }), options: this.props.options, className: "core-form-select" }))))));
    }
}
exports.Field = Field;
//# sourceMappingURL=Field.js.map