"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Common
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.withIsPressed = void 0;
const React = require("react");
/** withIsPressed is a React higher-order component that adds pointer and mouse events.
 * @public
 */
const withIsPressed = (
// eslint-disable-next-line @typescript-eslint/naming-convention
Component) => {
    return class WithIsPressed extends React.PureComponent {
        constructor() {
            super(...arguments);
            this.handleOnPointerDown = () => {
                this.changeIsPressed(true);
            };
            this.handleOnPointerUp = () => {
                this.changeIsPressed(false);
            };
            this.handleOnMouseLeave = () => {
                this.changeIsPressed(false);
            };
            this.changeIsPressed = (isPressed) => {
                if (this.props.isPressed === isPressed)
                    return;
                this.props.onIsPressedChange && this.props.onIsPressedChange(isPressed);
            };
        }
        render() {
            // eslint-disable-next-line @typescript-eslint/no-unused-vars
            const _a = this.props, { isPressed, onIsPressedChange } = _a, props = __rest(_a, ["isPressed", "onIsPressedChange"]); // todo: better solution to rest object of intersected type
            return (
            // eslint-disable-next-line jsx-a11y/no-static-element-interactions
            React.createElement("div", { className: "withispressed-wrapper", onMouseDown: this.handleOnPointerDown, onMouseUp: this.handleOnPointerUp, onTouchStart: this.handleOnPointerDown, onTouchEnd: this.handleOnPointerUp, onMouseLeave: this.handleOnMouseLeave },
                React.createElement(Component, Object.assign({}, props, this.state))));
        }
    };
};
exports.withIsPressed = withIsPressed;
//# sourceMappingURL=withIsPressed.js.map