"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Common
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.withOnOutsideClick = void 0;
const React = require("react");
/** withOnOutsideClick is a React higher-order component that adds outside click support.
 * @public
 */
const withOnOutsideClick = (
// eslint-disable-next-line @typescript-eslint/naming-convention
Component, defaultOnOutsideClick, useCapture = true, usePointerEvents = true) => {
    return class WithOnOutsideClick extends React.PureComponent {
        constructor() {
            super(...arguments);
            /** @internal */
            this.outsideClickContainerDiv = null;
            /** @internal */
            this.isDownOutside = false;
            /** @internal */
            this.handleDocumentClick = (e) => {
                if (!this.outsideClickContainerDiv || !(e.target instanceof Node) || this.outsideClickContainerDiv.contains(e.target))
                    return;
                return this.onOutsideClick(e);
            };
            /** @internal */
            this.handleDocumentPointerDown = (e) => {
                this.isDownOutside = true;
                if (this.outsideClickContainerDiv) {
                    // typically e.target test for instance of Node, but this is not working from pop out windows
                    this.isDownOutside = !!e.target && !this.outsideClickContainerDiv.contains(e.target);
                }
            };
            /** @internal */
            this.handleDocumentPointerUp = (e) => {
                let isUpOutside = true;
                if (this.outsideClickContainerDiv) {
                    // typically e.target test for instance of Node, but this is not working from pop out windows
                    isUpOutside = !!e.target && !this.outsideClickContainerDiv.contains(e.target);
                }
                const isOutsideClick = isUpOutside && this.isDownOutside;
                this.isDownOutside = false;
                isOutsideClick && this.onOutsideClick(e);
            };
            this.handleOutsideClickContainerDivSet = (outsideClickContainerDiv) => {
                this.outsideClickContainerDiv = outsideClickContainerDiv;
            };
        }
        /** @internal */
        isInCorePopup(element) {
            if (element.nodeName === "DIV") {
                if (element.classList && element.classList.contains("core-popup"))
                    return true;
                if (element.parentElement && this.isInCorePopup(element.parentElement))
                    return true;
            }
            else {
                // istanbul ignore else
                if (element.parentElement && this.isInCorePopup(element.parentElement))
                    return true;
            }
            return false;
        }
        /** @internal */
        onOutsideClick(e) {
            // istanbul ignore else
            if (e.target instanceof Node && e.target.nodeType === Node.ELEMENT_NODE) {
                // istanbul ignore else
                if (!this.props.closeOnNestedPopupOutsideClick && this.isInCorePopup(e.target))
                    return;
            }
            if (this.props.onOutsideClick)
                return this.props.onOutsideClick(e);
            else if (defaultOnOutsideClick)
                return defaultOnOutsideClick(e);
        }
        getParentDocument() {
            var _a, _b;
            return (_b = (_a = this.outsideClickContainerDiv) === null || _a === void 0 ? void 0 : _a.ownerDocument) !== null && _b !== void 0 ? _b : document;
        }
        componentDidMount() {
            const outsideClickParentDocument = this.getParentDocument();
            if (usePointerEvents) {
                outsideClickParentDocument.addEventListener("pointerdown", this.handleDocumentPointerDown, useCapture);
                outsideClickParentDocument.addEventListener("pointerup", this.handleDocumentPointerUp, useCapture);
            }
            else
                outsideClickParentDocument.addEventListener("click", this.handleDocumentClick, useCapture);
        }
        /** @internal */
        componentWillUnmount() {
            const outsideClickParentDocument = this.getParentDocument();
            if (usePointerEvents) {
                outsideClickParentDocument.removeEventListener("pointerdown", this.handleDocumentPointerDown, useCapture);
                outsideClickParentDocument.removeEventListener("pointerup", this.handleDocumentPointerUp, useCapture);
            }
            else
                outsideClickParentDocument.removeEventListener("click", this.handleDocumentClick, useCapture);
        }
        render() {
            const _a = this.props, { onOutsideClick, closeOnNestedPopupOutsideClick } = _a, props = __rest(_a, ["onOutsideClick", "closeOnNestedPopupOutsideClick"]); // eslint-disable-line @typescript-eslint/no-unused-vars
            return (React.createElement("div", { ref: this.handleOutsideClickContainerDivSet },
                React.createElement(Component, Object.assign({}, props))));
        }
    };
};
exports.withOnOutsideClick = withOnOutsideClick;
//# sourceMappingURL=withOnOutsideClick.js.map