"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Common
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.withTimeout = void 0;
const React = require("react");
const Timer_1 = require("../utils/Timer");
/** withTimeout is a React higher-order component that adds timeout support.
 * @public
 */
const withTimeout = (
// eslint-disable-next-line @typescript-eslint/naming-convention
Component) => {
    return class WithTimeout extends React.PureComponent {
        constructor() {
            super(...arguments);
            this.timer = new Timer_1.Timer(0);
        }
        componentDidMount() {
            this.timer.setOnExecute(() => this.props.onTimeout && this.props.onTimeout());
            this.startTimer(this.props.timeout);
        }
        componentDidUpdate(_prevProps) {
            this.startTimer(this.props.timeout);
        }
        componentWillUnmount() {
            this.timer.stop();
        }
        render() {
            const _a = this.props, { timeout, onTimeout } = _a, props = __rest(_a, ["timeout", "onTimeout"]); // eslint-disable-line @typescript-eslint/no-unused-vars
            return (React.createElement(Component, Object.assign({}, props, this.state)));
        }
        startTimer(timeout) {
            if (this.timer.isRunning)
                return;
            this.timer.delay = timeout;
            this.timer.start();
        }
    };
};
exports.withTimeout = withTimeout;
//# sourceMappingURL=withTimeout.js.map