"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Icon
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Icon = void 0;
require("./IconComponent.scss");
const React = require("react");
const classnames = require("classnames");
const ui_abstract_1 = require("@bentley/ui-abstract");
const SvgSprite_1 = require("./SvgSprite");
/** Icon Functional component displays an icon based on an [[IconSpec]].
 * @public
 */
function Icon(props) {
    if (!props.iconSpec)
        return null;
    const iconString = (typeof props.iconSpec === "string" || props.iconSpec instanceof ui_abstract_1.ConditionalStringValue) ?
        ui_abstract_1.ConditionalStringValue.getValue(props.iconSpec) : undefined;
    if (iconString) {
        const svgSource = ui_abstract_1.IconSpecUtilities.getSvgSource(iconString);
        // if string begins with "svg:" then we assume it was imported (into extension source file) using webpack loader svg-sprite-loader
        if (svgSource !== undefined)
            return (React.createElement("i", { className: classnames("icon", "core-svg-icon", props.className), style: props.style },
                React.createElement(SvgSprite_1.SvgSprite, { src: svgSource })));
        return (React.createElement("i", { className: classnames("icon", iconString, props.className), style: props.style }));
    }
    return (React.createElement("i", { className: classnames("icon", "core-svg-icon", props.className), style: props.style }, props.iconSpec));
}
exports.Icon = Icon;
//# sourceMappingURL=IconComponent.js.map