/** @packageDocumentation
 * @module Checkbox
 */
import "./ImageCheckBox.scss";
import * as React from "react";
import { CommonProps } from "../utils/Props";
/** Properties for the [[ImageCheckBox]] component
 * @public
 */
export interface ImageCheckBoxProps extends CommonProps {
    /** Image for the "checked" state */
    imageOn: string | React.ReactNode;
    /** Image for the "unchecked" (default) state */
    imageOff: string | React.ReactNode;
    /** Determine if the item is checked or not */
    checked?: boolean;
    /** Determine if the item is disabled or not */
    disabled?: boolean;
    /** Function called when item is clicked. */
    onClick?: (checked: boolean) => any;
    /** Custom CSS class name for the checkbox input element */
    inputClassName?: string;
    /** Custom CSS Style for the checkbox input element */
    inputStyle?: React.CSSProperties;
    /** Tooltip to be displayed when mouse is hovered over the checkbox */
    tooltip?: string;
    /** If true, draw a border around the image checkbox */
    border?: boolean;
    /** Provides ability to return reference to HTMLInputElement */
    inputRef?: React.Ref<HTMLInputElement>;
}
/**
 * ImageCheckBox React component shows a checked or unchecked image
 * @public
 */
export declare class ImageCheckBox extends React.PureComponent<ImageCheckBoxProps> {
    private _onChange;
    private _onInputClick;
    private _onLabelClick;
    /** @internal */
    render(): JSX.Element;
}
//# sourceMappingURL=ImageCheckBox.d.ts.map