"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Checkbox
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ImageCheckBox = void 0;
require("./ImageCheckBox.scss");
const classnames = require("classnames");
const React = require("react");
const IconComponent_1 = require("../icons/IconComponent");
/**
 * ImageCheckBox React component shows a checked or unchecked image
 * @public
 */
class ImageCheckBox extends React.PureComponent {
    constructor() {
        super(...arguments);
        this._onChange = (e) => {
            // istanbul ignore next
            if (e && e.stopPropagation)
                e.stopPropagation();
            // istanbul ignore else
            if (this.props.onClick) {
                this.props.onClick(e.target.checked);
            }
        };
        this._onInputClick = (e) => {
            // istanbul ignore next
            if (e && e.stopPropagation)
                e.stopPropagation();
        };
        this._onLabelClick = (e) => {
            // istanbul ignore next
            if (e && e.stopPropagation)
                e.stopPropagation();
        };
    }
    /** @internal */
    render() {
        const checkBoxClass = classnames("core-image-checkbox", this.props.className);
        const imageClass = classnames("image", this.props.border && "image-checkbox-border");
        const iconSpec = this.props.checked ? this.props.imageOn : this.props.imageOff;
        return (
        /* eslint-disable jsx-a11y/no-noninteractive-element-interactions */
        /* eslint-disable-next-line jsx-a11y/click-events-have-key-events */
        React.createElement("label", { className: checkBoxClass, style: this.props.style, onClick: this._onLabelClick, title: this.props.tooltip },
            React.createElement("input", { type: "checkbox", className: this.props.inputClassName, style: this.props.inputStyle, checked: this.props.checked, disabled: this.props.disabled, onChange: this._onChange, onClick: this._onInputClick, ref: this.props.inputRef }),
            React.createElement("span", { className: imageClass },
                React.createElement(IconComponent_1.Icon, { iconSpec: iconSpec }))));
    }
}
exports.ImageCheckBox = ImageCheckBox;
//# sourceMappingURL=ImageCheckBox.js.map