"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Inputs
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Input = void 0;
const classnames = require("classnames");
const React = require("react");
const useRefs_1 = require("../utils/hooks/useRefs");
// Defined using following pattern (const Input at bottom) to ensure useful API documentation is extracted
const ForwardRefInput = React.forwardRef(function ForwardRefInput(props, ref) {
    const { className, style, setFocus, nativeKeyHandler } = props, otherProps = __rest(props, ["className", "style", "setFocus", "nativeKeyHandler"]); // eslint-disable-line @typescript-eslint/no-unused-vars
    const inputElementRef = React.useRef();
    const refs = useRefs_1.useRefs(inputElementRef, ref); // combine ref needed for target with the forwardRef needed by the Parent when parent is a Type Editor.
    React.useEffect(() => {
        const currentElement = inputElementRef.current;
        const currentHandler = nativeKeyHandler;
        if (currentElement && currentHandler) {
            currentElement.addEventListener("keydown", currentHandler);
        }
        return () => {
            if (currentHandler && currentElement) {
                currentElement.removeEventListener("keydown", currentHandler);
            }
        };
    }, [nativeKeyHandler]);
    React.useEffect(() => {
        if (inputElementRef.current && setFocus)
            inputElementRef.current.focus();
    }, [setFocus]);
    const handleFocus = React.useCallback((event) => {
        event.currentTarget.select();
    }, []);
    return (React.createElement("input", Object.assign({ ref: refs, type: "text" }, otherProps, { onFocus: handleFocus, className: classnames("uicore-inputs-input", className), style: style })));
});
/** Basic text input, is a wrapper for the `<input type="text">` HTML element.
 * @public
 */
exports.Input = ForwardRefInput;
//# sourceMappingURL=Input.js.map