"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Inputs
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Textarea = void 0;
const classnames = require("classnames");
const React = require("react");
const useRefs_1 = require("../utils/hooks/useRefs");
// Defined using following pattern (const Input at bottom) to ensure useful API documentation is extracted
const ForwardRefTextarea = React.forwardRef(function ForwardRefTextarea(props, ref) {
    const { className, style, rows, setFocus } = props, otherProps = __rest(props, ["className", "style", "rows", "setFocus"]); // eslint-disable-line @typescript-eslint/no-unused-vars
    const textRows = undefined !== rows ? rows : 3;
    const textAreaElementRef = React.useRef();
    const refs = useRefs_1.useRefs(textAreaElementRef, ref); // combine ref needed for target with the forwardRef needed by the Parent when parent is a Type Editor.
    React.useEffect(() => {
        if (textAreaElementRef.current && setFocus)
            textAreaElementRef.current.focus();
    }, [setFocus]);
    const handleFocus = React.useCallback((event) => {
        event.currentTarget.select();
    }, []);
    return (React.createElement("textarea", Object.assign({}, otherProps, { ref: refs, rows: textRows, onFocus: handleFocus, className: classnames("uicore-inputs-textarea", className), style: style })));
});
/** Basic textarea component
 * @public
 */
exports.Textarea = ForwardRefTextarea;
//# sourceMappingURL=Textarea.js.map