/** @packageDocumentation
 * @module Inputs
 */
import "./NumberInput.scss";
import * as React from "react";
import { InputProps } from "../Input";
/** Step function prototype for [[NumberInput]] component
 * @beta
 */
export declare type StepFunctionProp = number | ((direction: string) => number | undefined);
/** Properties for the [[NumberInput]] component
 * @beta
 */
export interface NumberInputProps extends Omit<InputProps, "min" | "max" | "step" | "onChange"> {
    /** Numeric value, set to `undefined` to show placeholder text */
    value?: number;
    /** CSS class name for the NumberInput component container div */
    containerClassName?: string;
    /** number or function	Number.MIN_SAFE_INTEGER */
    min?: number;
    /** number or function	defaults to Number.MAX_SAFE_INTEGER */
    max?: number;
    /** increment step value used while incrementing or decrementing (up/down buttons or arrow keys) defaults to 1. */
    step?: StepFunctionProp;
    /** number of decimal places, defaults to 0 */
    precision?: number;
    /** function parseFloat */
    parse?: ((value: string) => number | null | undefined);
    /** function optional formatting function that takes the number value and the internal formatted value in case function just adds prefix or suffix. */
    format?: (num: number | null | undefined, formattedValue: string) => string;
    /** Set to true to "snap" to the closest step value while incrementing or decrementing (up/down buttons or arrow keys). */
    snap?: boolean;
    /** Function to call when value is changed. */
    onChange?: (value: number | undefined, stringValue: string) => void;
    /** if true up/down buttons are shown larger and side by side */
    showTouchButtons?: boolean;
    /** Provides ability to return reference to HTMLInputElement */
    ref?: React.Ref<HTMLInputElement>;
}
/** Input component for numbers with up and down buttons to increment and decrement the value.
 * @beta
 */
export declare const NumberInput: (props: NumberInputProps) => JSX.Element | null;
//# sourceMappingURL=NumberInput.d.ts.map