"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Loading
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.percentInRange = exports.LoadingBar = void 0;
require("./LoadingBar.scss");
const classnames = require("classnames");
const React = require("react");
/**
 * A loading bar with optional percentage text.
 * @public
 */
class LoadingBar extends React.PureComponent {
    render() {
        const percent = `${percentInRange(this.props.percent)}%`;
        const containerClass = classnames(this.props.className, "core-lb");
        return (React.createElement("div", { className: containerClass, style: this.props.style },
            React.createElement("div", { className: "lb-container", style: { height: this.props.barHeight } },
                React.createElement("div", { className: "fill", style: { width: percent } })),
            this.props.showPercentage && React.createElement("span", { className: "percent" }, percent)));
    }
}
exports.LoadingBar = LoadingBar;
LoadingBar.defaultProps = {
    barHeight: 4,
};
/** Sanity check to keep percentage between 0 & 100
 * @internal
 */
function percentInRange(percent) {
    let value = Math.min(percent, 100);
    value = Math.max(value, 0);
    return value;
}
exports.percentInRange = percentInRange;
//# sourceMappingURL=LoadingBar.js.map