"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Loading
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoadingPrompt = void 0;
require("./LoadingPrompt.scss");
const classnames = require("classnames");
const React = require("react");
const LoadingBar_1 = require("./LoadingBar");
const LoadingSpinner_1 = require("./LoadingSpinner");
const LoadingStatus_1 = require("./LoadingStatus");
const ProgressBar_1 = require("../progress-indicators/ProgressBar");
/**
 * A component to display during loading that optionally shows percentage, status text and a cancel button.
 * @public
 */
class LoadingPrompt extends React.PureComponent {
    render() {
        // eslint-disable-next-line deprecation/deprecation
        const isDeterminate = this.props.isDeterminate || this.props.isDeterministic;
        return (React.createElement("div", { className: classnames("core-loadingprompt", this.props.className), style: this.props.style },
            React.createElement("span", { className: "title" }, this.props.title),
            this.props.message && React.createElement("span", { className: "message" }, this.props.message),
            isDeterminate && React.createElement(LoadingBar_1.LoadingBar, { style: { width: "100%" }, percent: this.props.percent, showPercentage: this.props.showPercentage }),
            (isDeterminate && this.props.showStatus) &&
                React.createElement(LoadingStatus_1.LoadingStatus, { style: { marginTop: ".5em", width: "100%", fontSize: ".75em" }, percent: this.props.percent, message: this.props.status }),
            !isDeterminate && (this.props.showIndeterminateBar ? React.createElement(ProgressBar_1.ProgressBar, { indeterminate: true }) : React.createElement(LoadingSpinner_1.LoadingSpinner, null)),
            this.props.showCancel && React.createElement("button", { className: "loading-prompt-cancel", type: "button", onClick: this.props.onCancel }, "Cancel")));
    }
}
exports.LoadingPrompt = LoadingPrompt;
LoadingPrompt.defaultProps = {
    showPercentage: false,
    showStatus: false,
    showCancel: false,
    isDeterminate: false,
    showIndeterminateBar: false,
    percent: 0,
    status: "",
};
//# sourceMappingURL=LoadingPrompt.js.map