"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Loading
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoadingStatus = void 0;
require("./LoadingStatus.scss");
const classnames = require("classnames");
const React = require("react");
/**
 * A loading indicator that shows status text along with the percentage.
 * @public
 */
class LoadingStatus extends React.PureComponent {
    // sanity check to keep percentage between 0 & 100
    inRange(percent) {
        let value = Math.min(percent, 100);
        value = Math.max(value, 0);
        return value;
    }
    render() {
        const percent = `${this.inRange(this.props.percent)}%`;
        const containerClass = classnames(this.props.className, "loading-status-container");
        return (React.createElement("div", { className: containerClass, style: this.props.style },
            React.createElement("span", { className: "loading-status-message" }, this.props.message),
            React.createElement("span", { className: "loading-status-percent" }, percent)));
    }
}
exports.LoadingStatus = LoadingStatus;
LoadingStatus.defaultProps = {
    message: "",
    percent: 0,
};
//# sourceMappingURL=LoadingStatus.js.map