"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Loading
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Spinner = exports.SpinnerSize = void 0;
require("./Spinner.scss");
const React = require("react");
// cspell:ignore xlarge
/** Size for [[Spinner]] component
 * @public
 */
var SpinnerSize;
(function (SpinnerSize) {
    /** width/height of 16px */
    SpinnerSize[SpinnerSize["Small"] = 0] = "Small";
    /** width/height of 32px */
    SpinnerSize[SpinnerSize["Medium"] = 1] = "Medium";
    /** width/height of 64px */
    SpinnerSize[SpinnerSize["Large"] = 2] = "Large";
    /** width/height of 96px */
    SpinnerSize[SpinnerSize["XLarge"] = 3] = "XLarge";
})(SpinnerSize = exports.SpinnerSize || (exports.SpinnerSize = {}));
/**
 * An indeterminate spinner component.
 * @public
 */
class Spinner extends React.PureComponent {
    render() {
        let sizeClass;
        if (this.props.sizeClass)
            sizeClass = this.props.sizeClass;
        else {
            switch (this.props.size) {
                case SpinnerSize.Small:
                    sizeClass = "core-spinner-small";
                    break;
                case SpinnerSize.Large:
                    sizeClass = "core-spinner-large";
                    break;
                case SpinnerSize.XLarge:
                    sizeClass = "core-spinner-xlarge";
                    break;
                case SpinnerSize.Medium:
                default:
                    sizeClass = "core-spinner-medium";
                    break;
            }
        }
        return (React.createElement("div", { className: sizeClass }));
    }
}
exports.Spinner = Spinner;
//# sourceMappingURL=Spinner.js.map