/** @packageDocumentation
 * @module Dialog
 */
import "./MessageBox.scss";
import * as React from "react";
import { DialogButtonDef } from "../dialog/Dialog";
import { CommonProps } from "../utils/Props";
/** Message Severity enum.
 * @public
 */
export declare enum MessageSeverity {
    None = 0,
    Information = 1,
    Question = 2,
    Warning = 3,
    Error = 4,
    Fatal = 5
}
/** Properties for the [[MessageBox]] component
 * @public
 */
export interface MessageBoxProps extends CommonProps {
    /** Severity of MessageBox */
    severity: MessageSeverity;
    /** whether to show dialog or not */
    opened: boolean;
    /** List of [[DialogButtonDef]] objects specifying buttons and associated onClick events */
    buttonCluster: DialogButtonDef[];
    /** Title to show in title bar of dialog  */
    title?: string | JSX.Element;
    /** onClick event for X button for dialog */
    onClose?: () => void;
    /** 'keyup' event for <Esc> key */
    onEscape?: () => void;
    /** minimum width that the dialog may be resized to. Default: 400 */
    minWidth?: number;
    /** minimum height that the dialog may be resized to. Default: 400 */
    minHeight?: number;
    /** initial width of dialog.
     * Displayed in px if value is a number, otherwise displayed in specified CSS unit.
     * Default: "50%"
     */
    width?: string | number;
    /** initial height of dialog.
     * Displayed in px if value is a number, otherwise displayed in specified CSS unit.
     * Default: ""
     */
    height?: string | number;
    /** Whether to show background overlay. Default: true */
    modal?: boolean;
    /** Custom CSS class name for the content */
    contentClassName?: string;
    /** Custom CSS Style for the content */
    contentStyle?: React.CSSProperties;
}
/** Message Box React component.
 * @public
 */
export declare class MessageBox extends React.PureComponent<MessageBoxProps> {
    static defaultProps: Partial<MessageBoxProps>;
    render(): JSX.Element;
}
/** Properties for the [[MessageContainer]] component
 * @public
 */
export interface MessageContainerProps extends CommonProps {
    severity: MessageSeverity;
}
/** Message Container React component.
 * @public
 */
export declare class MessageContainer extends React.PureComponent<MessageContainerProps> {
    static getIconClassName(severity: MessageSeverity, hollow?: boolean): string;
    render(): JSX.Element;
}
//# sourceMappingURL=MessageBox.d.ts.map