"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Dialog
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageContainer = exports.MessageBox = exports.MessageSeverity = void 0;
require("./MessageBox.scss");
const classnames = require("classnames");
const React = require("react");
const Dialog_1 = require("../dialog/Dialog");
/** Message Severity enum.
 * @public
 */
var MessageSeverity;
(function (MessageSeverity) {
    MessageSeverity[MessageSeverity["None"] = 0] = "None";
    MessageSeverity[MessageSeverity["Information"] = 1] = "Information";
    MessageSeverity[MessageSeverity["Question"] = 2] = "Question";
    MessageSeverity[MessageSeverity["Warning"] = 3] = "Warning";
    MessageSeverity[MessageSeverity["Error"] = 4] = "Error";
    MessageSeverity[MessageSeverity["Fatal"] = 5] = "Fatal";
})(MessageSeverity = exports.MessageSeverity || (exports.MessageSeverity = {}));
/** Message Box React component.
 * @public
 */
class MessageBox extends React.PureComponent {
    render() {
        return (React.createElement(Dialog_1.Dialog, { title: this.props.title, buttonCluster: this.props.buttonCluster, opened: this.props.opened, width: this.props.width, onClose: this.props.onClose, onEscape: this.props.onEscape, modal: this.props.modal, className: this.props.className, style: this.props.style },
            React.createElement(MessageContainer, { severity: this.props.severity, className: this.props.contentClassName, style: this.props.contentStyle }, this.props.children)));
    }
}
exports.MessageBox = MessageBox;
MessageBox.defaultProps = {
    minWidth: 400,
    minHeight: 400,
    width: "512px",
    modal: true,
};
/** Message Container React component.
 * @public
 */
class MessageContainer extends React.PureComponent {
    static getIconClassName(severity, hollow) {
        let iconClassName = "";
        switch (severity) {
            case MessageSeverity.None:
                iconClassName = hollow ? "icon-status-success-hollow" : "icon-status-success" + " core-message-box-success";
                break;
            case MessageSeverity.Information:
                iconClassName = hollow ? "icon-info-hollow" : "icon-info" + " core-message-box-information";
                break;
            case MessageSeverity.Question:
                iconClassName = hollow ? "icon-help-hollow" : "icon-help" + " core-message-box-question";
                break;
            case MessageSeverity.Warning:
                iconClassName = hollow ? "icon-status-warning" : "icon-status-warning" + " core-message-box-warning"; // TODO - need icon-status-warning-hollow icon
                break;
            case MessageSeverity.Error:
                iconClassName = hollow ? "icon-status-error-hollow" : "icon-status-error" + " core-message-box-error";
                break;
            case MessageSeverity.Fatal:
                iconClassName = hollow ? "icon-status-rejected" : "icon-status-rejected" + " core-message-box-fatal";
                break;
        }
        return iconClassName;
    }
    render() {
        const iconClassName = classnames("icon", "core-message-box-icon", MessageContainer.getIconClassName(this.props.severity));
        return (React.createElement("div", { className: "core-message-box-container" },
            React.createElement("div", { className: iconClassName }),
            React.createElement("div", { className: classnames("core-message-box-content", this.props.className), style: this.props.style }, this.props.children)));
    }
}
exports.MessageContainer = MessageContainer;
//# sourceMappingURL=MessageBox.js.map