"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Loading
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProgressBar = void 0;
const classnames = require("classnames");
const React = require("react");
const LoadingBar_1 = require("../loading/LoadingBar");
/**
 * ProgressBar React component shows a horizontal progress bar.
 * The determinate bar reflects a percentage and the indeterminate bar continuously animates.
 * @beta
 */
function ProgressBar(props) {
    const percent = props.percent !== undefined ? LoadingBar_1.percentInRange(props.percent) : 0;
    const outerStyle = Object.assign(Object.assign({}, props.style), { height: props.barHeight !== undefined ? `${props.barHeight}px` : undefined });
    const innerStyle = {
        width: !props.indeterminate ? `${percent}%` : undefined,
    };
    const innerClass = !props.indeterminate ? "uicore-progress-bar-determinate" : "uicore-progress-bar-indeterminate";
    const hasLabel = props.labelLeft !== undefined || props.labelRight !== undefined;
    const multipleLabels = props.labelLeft !== undefined && props.labelRight !== undefined;
    const bar = (React.createElement("div", { className: classnames("uicore-progress-bar", props.className), style: outerStyle },
        React.createElement("div", { className: innerClass, style: innerStyle })));
    const content = !hasLabel ?
        bar :
        (React.createElement("div", { className: "uicore-progress-bar-labeled" },
            bar,
            React.createElement("div", { className: "uicore-label" },
                multipleLabels && React.createElement(React.Fragment, null,
                    React.createElement("span", null, props.labelLeft),
                    React.createElement("span", null, props.labelRight)),
                !multipleLabels && React.createElement(React.Fragment, null,
                    props.labelLeft,
                    props.labelRight))));
    return content;
}
exports.ProgressBar = ProgressBar;
//# sourceMappingURL=ProgressBar.js.map