/** @packageDocumentation
 * @module Loading
 */
import * as React from "react";
import { CommonProps } from "../utils/Props";
import { SpinnerSize } from "../loading/Spinner";
/**
 * Properties for [[ProgressSpinner]] component
 * @beta
 */
export interface ProgressSpinnerProps extends CommonProps {
    /**
     * Spinner percentage. Should be a number between 0 and 100.
     * @default 0
     */
    value?: number;
    /**
     * Spinner variant. If true, value will be ignored.
     * @default false
     */
    indeterminate?: boolean;
    /**
     * If true, spinner will be full, green, and display a checkmark.
     * @default false
     */
    success?: boolean;
    /**
     * If true, spinner will be full, red, and display an X.
     * @default false
     */
    error?: boolean;
    /**
     * Size of spinner
     * @default width/height of 40px
     */
    size?: SpinnerSize;
    /**
     * Child components
     */
    children?: React.ReactNode;
}
/**
 * Circular Progress Indicator that supports determinate and indeterminate modes.
 * @beta
 */
export declare function ProgressSpinner(props: ProgressSpinnerProps): JSX.Element;
//# sourceMappingURL=ProgressSpinner.d.ts.map