"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Loading
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProgressSpinner = void 0;
const classnames = require("classnames");
const React = require("react");
const IconComponent_1 = require("../icons/IconComponent");
const Spinner_1 = require("../loading/Spinner");
/**
 * Circular Progress Indicator that supports determinate and indeterminate modes.
 * @beta
 */
function ProgressSpinner(props) {
    const { value = 0, indeterminate = false, success = false, error = false, style = {}, size, children, } = props;
    let outerClassName = classnames("uicore-progress-spinner");
    const outerStyle = Object.assign({}, style);
    const fillStyle = {};
    // Ensure value is bounded 0 - 100;
    const dashOffset = 100 - Math.min(Math.max(value, 0), 100);
    let content;
    if (error) {
        outerClassName = classnames(outerClassName, "error");
        content = React.createElement(IconComponent_1.Icon, { iconSpec: "icon-close-2" });
    }
    else if (success) {
        outerClassName = classnames(outerClassName, "success");
        content = (React.createElement(IconComponent_1.Icon, { iconSpec: "icon-checkmark" }));
    }
    else if (indeterminate) {
        outerClassName = classnames(outerClassName, "indeterminate");
        content = children;
    }
    else {
        outerClassName = classnames(outerClassName, "determinate");
        fillStyle.strokeDashoffset = dashOffset;
        content = children;
    }
    setDefaultDimensions(outerStyle, size);
    return (React.createElement("div", { className: outerClassName, style: outerStyle },
        React.createElement("svg", { className: "spinner", viewBox: "0 0 40 40" },
            React.createElement("circle", { className: "shape", cx: "20", cy: "20", r: "15.91549" }),
            React.createElement("circle", { className: "fill", cx: "20", cy: "20", r: "15.91549", style: fillStyle })),
        content && React.createElement("span", { className: "uicore-progress-spinner-content" }, content)));
}
exports.ProgressSpinner = ProgressSpinner;
const setDefaultDimensions = (style, inSize) => {
    let size = 40;
    if (inSize !== undefined) {
        switch (inSize) {
            case Spinner_1.SpinnerSize.Small:
                size = 16;
                break;
            case Spinner_1.SpinnerSize.Medium:
                size = 32;
                break;
            case Spinner_1.SpinnerSize.Large:
                size = 64;
                break;
            case Spinner_1.SpinnerSize.XLarge:
                size = 96;
                break;
        }
    }
    style.width = style.width ? style.width : size;
    style.height = style.height ? style.height : size;
};
//# sourceMappingURL=ProgressSpinner.js.map