/** @packageDocumentation
 * @module Select
 */
import * as React from "react";
import { CommonProps } from "../utils/Props";
/** Properties for a Select option
 * @public
 */
export interface SelectOption {
    /** Label of the option. If `value` is not set when using SelectOption[], also serves as the value. */
    label: string;
    /** Value of the option when using SelectOption[].  */
    value?: string | number | readonly string[];
    /** Indicates whether the option is disabled. */
    disabled?: boolean;
}
/** Properties for [[Select]] component
 * @public
 */
export interface SelectProps extends React.SelectHTMLAttributes<HTMLSelectElement>, CommonProps {
    /** Options for Select dropdown.
     * @example
     * // Example of {[key: string]: (string | SelectOption)} usage:
     * <Select options={{
     *  option1: "Option 1",
     *  option2: "Option 2",
     *  option3: {label: "Option 3", disabled: true},
     * }} />
     *
     * // Example of (string | SelectOption)[] usage:
     * <Select options={[
     *  "Option 1",
     *  "Option 2",
     *  {label: "Option 3", value: "option3", disabled: true},
     * ]} />
     * }
     */
    options: (string | SelectOption)[] | {
        [key: string]: (string | SelectOption);
    };
    /** Indicates whether to set focus to the select element */
    setFocus?: boolean;
    /** Provides ability to return reference to HTMLSelectElement */
    ref?: React.Ref<HTMLSelectElement>;
}
/** Basic select component is a wrapper for the `<select>` HTML element.
 * @public
 */
export declare const Select: (props: SelectProps) => JSX.Element | null;
//# sourceMappingURL=Select.d.ts.map