"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Select
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Select = void 0;
const classnames = require("classnames");
const React = require("react");
const useRefs_1 = require("../utils/hooks/useRefs");
function getCurrentDefaultValue(defaultValue, placeholderValue) {
    if (defaultValue)
        return defaultValue;
    return placeholderValue;
}
function getOptionLabel(option) {
    return (typeof option === "string") ? option : option.label;
}
function getOptionValue(option) {
    return (typeof option === "string") ? option : (undefined !== option.value ? option.value : option.label);
}
function getOptionDisabled(option) {
    return (typeof option === "string") ? undefined : option.disabled;
}
const ForwardRefSelect = React.forwardRef(function ForwardRefSelect(props, ref) {
    const selectElement = React.useRef(null);
    const placeholderValue = React.useRef("placeholder");
    const isInitialMount = React.useRef(true);
    const refs = useRefs_1.useRefs(selectElement, ref); // combine ref needed for target with the forwardRef needed by the Parent when parent is a Type Editor.
    React.useEffect(() => {
        if (props.setFocus && selectElement.current)
            selectElement.current.focus();
    }, [props]);
    React.useEffect(() => {
        isInitialMount.current = false;
    }, []);
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    const { value: selectValue, required, options, setFocus, className, defaultValue } = props, otherProps = __rest(props, ["value", "required", "options", "setFocus", "className", "defaultValue"]); // pluck off values that will be explicitly set below
    const showPlaceholder = React.useMemo(() => props.placeholder && (undefined === selectValue || selectValue === placeholderValue.current) && !defaultValue, [defaultValue, selectValue, props.placeholder]);
    const isRequired = React.useMemo(() => showPlaceholder || required, [required, showPlaceholder]);
    const currentDefaultValue = React.useMemo(() => getCurrentDefaultValue(defaultValue, showPlaceholder ? placeholderValue.current : undefined), [defaultValue, showPlaceholder]);
    const value = (!isInitialMount.current && undefined === selectValue) ? currentDefaultValue : selectValue;
    return (React.createElement("select", Object.assign({ ref: refs }, otherProps, { required: isRequired, className: classnames("uicore-inputs-select", className), value: value, defaultValue: value === undefined ? currentDefaultValue : undefined }),
        showPlaceholder &&
            React.createElement("option", { className: "placeholder", disabled: true, key: "", value: placeholderValue.current }, props.placeholder),
        options instanceof Array ?
            options.map((option, index) => (React.createElement("option", { key: index, value: getOptionValue(option), disabled: getOptionDisabled(option) }, getOptionLabel(option))))
            :
                Object.keys(options).map((key) => (React.createElement("option", { key: key, value: key, disabled: getOptionDisabled(options[key]) }, getOptionLabel(options[key]))))));
});
/** Basic select component is a wrapper for the `<select>` HTML element.
 * @public
 */
exports.Select = ForwardRefSelect;
//# sourceMappingURL=Select.js.map