"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Select
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThemedSelect = void 0;
require("./themed-select.scss");
const classnames = require("classnames");
const React = require("react");
const react_select_1 = require("react-select");
const UiCore_1 = require("../UiCore");
const getCssVariable_1 = require("../utils/getCssVariable");
const modalHelper_1 = require("./modalHelper");
const ThemedMenu = (props) => {
    return (React.createElement("div", { className: "uicore-reactSelectTop" },
        React.createElement(react_select_1.components.Menu, Object.assign({}, props))));
};
/** ThemedSelect is a wrapper for react-select with iModel.js UI theming applied
 * @beta
 */
// eslint-disable-next-line @typescript-eslint/naming-convention
function ThemedSelect(props) {
    var _a;
    const noOptionLabel = React.useRef();
    const defaultOptionMessage = React.useCallback(() => {
        if (!noOptionLabel.current) {
            noOptionLabel.current = UiCore_1.UiCore.translate("reactselect.noSelectOption");
        }
        return noOptionLabel.current;
    }, [noOptionLabel]);
    const noOptionFunction = (_a = props.noOptionsMessage) !== null && _a !== void 0 ? _a : defaultOptionMessage;
    const selectClassName = classnames("uicore-reactSelectTop", props.className);
    const portalTarget = !!props.isMenuFixed ? undefined : modalHelper_1.getParentSelector();
    const _b = props, { 
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    classNamePrefix, className, noOptionsMessage, menuPortalTarget, isMenuFixed, styles, components, divRef, ref } = _b, 
    // eslint-disable-next-line comma-dangle
    otherProps = __rest(_b, ["classNamePrefix", "className", "noOptionsMessage", "menuPortalTarget", "isMenuFixed", "styles", "components", "divRef", "ref"]) // pass-through props
    ;
    const selectStyles = Object.assign(Object.assign({}, props.styles), { menuPortal: (base) => (Object.assign(Object.assign({}, base), { zIndex })) });
    const zIndex = getCssVariable_1.getCssVariableAsNumber("--uicore-z-index-dialog-popup");
    return (React.createElement("div", { className: selectClassName, ref: divRef },
        React.createElement(react_select_1.default, Object.assign({ ref: ref, classNamePrefix: "react-select", noOptionsMessage: noOptionFunction, menuPortalTarget: portalTarget, styles: selectStyles, 
            // eslint-disable-next-line @typescript-eslint/naming-convention
            components: Object.assign({ Menu: ThemedMenu }, props.components) }, otherProps))));
}
exports.ThemedSelect = ThemedSelect;
//# sourceMappingURL=ThemedSelect.js.map