/** @packageDocumentation
 * @module SplitButton
 */
import "./SplitButton.scss";
import * as React from "react";
import { IconSpec } from "../icons/IconComponent";
import { CommonProps } from "../utils/Props";
import { RelativePosition } from "@bentley/ui-abstract";
import { ButtonType } from "../button/Button";
/** @internal */
export declare enum SplitButtonActionType {
    ContextMenu = 0,
    List = 1
}
/** Properties for [[SplitButton]] component
 * @public
 */
export interface SplitButtonProps extends CommonProps {
    /** Label to display in click area. */
    label: string | React.ReactNode;
    /** Listens for click events on button area */
    onClick?: (event: any) => any;
    /** Listens for execute on button area */
    onExecute?: () => any;
    /** Specifies icon for Splitbutton component */
    icon?: IconSpec;
    /** Indicates whether to draw a border around the button */
    drawBorder?: boolean;
    /** ToolTip text */
    toolTip?: string;
    /** Direction relative to the button to which the popup is expanded (defaults to Bottom) */
    popupPosition?: RelativePosition;
    /** 4 styles to tweak the content of the button */
    buttonType?: ButtonType;
    /** @internal */
    initialExpanded?: boolean;
}
/** @internal */
interface SplitButtonState {
    expanded: boolean;
}
/**
 * SplitButton with an action button on the left and an arrow button that displays a context menu on the right.
 * @public
 */
export declare class SplitButton extends React.Component<SplitButtonProps, SplitButtonState> {
    private _arrowElement;
    private _buttonRef;
    private _closing;
    /** @internal */
    readonly state: Readonly<SplitButtonState>;
    constructor(props: SplitButtonProps);
    render(): JSX.Element;
    private _handleKeyUp;
    private _open;
    private _handleArrowClick;
    private _handleClose;
}
export {};
//# sourceMappingURL=SplitButton.d.ts.map