/** @packageDocumentation
 * @module Tabs
 */
import * as React from "react";
import { CommonProps } from "../utils/Props";
import { Orientation } from "../enums/Orientation";
/** TabLabel provides ability to define label, icon, and tooltip for a tab entry. The tooltip can be defined as JSX|Element
 *  to support react-tooltip component or a string that will be use to set the title property.
 * @beta
 */
export interface TabLabel {
    label: string;
    subLabel?: string;
    icon?: string | JSX.Element;
    tabId: string;
    /** tooltip allows JSX.Element to support styled tooltips like react-tooltip. */
    tooltip?: string | JSX.Element;
    disabled?: boolean;
}
/** Properties for the [[HorizontalTabs]] and [[VerticalTabs]] components
 * @public
 */
export interface TabsProps extends React.AllHTMLAttributes<HTMLUListElement>, CommonProps {
    /** Text shown for each tab @beta */
    labels: Array<string | TabLabel>;
    /** Handler for activating a tab */
    onActivateTab?: (index: number) => any;
    /** Index of the initial active tab */
    activeIndex?: number;
    /** Indicates whether the bar on the active tab is green instead of the default blue */
    green?: boolean;
    /** Handler for clicking on a label
     * @deprecated Use `onActivateTab` instead
     */
    onClickLabel?: (index: number) => any;
}
/** State for [[Tabs]] component
 * @internal
 */
interface TabsState {
    activeIndex: number;
}
/** Properties for the base [[Tabs]] component
 * @public
 */
export interface MainTabsProps extends TabsProps {
    /** Main CSS class name */
    mainClassName: string;
    /** Orientation of the Tabs list */
    orientation: Orientation;
}
/** Tabs meant to represent the current position in a page/section
 * @public
 */
export declare class Tabs extends React.PureComponent<MainTabsProps, TabsState> {
    private _anchorRefs;
    private _itemKeyboardNavigator;
    constructor(props: MainTabsProps);
    private validateActiveIndex;
    /** @internal */
    componentDidMount(): void;
    /** @internal */
    componentDidUpdate(prevProps: MainTabsProps): void;
    private _handleFocusItem;
    private _handleTabClick;
    /** Handle keydown on tabs */
    private _handleKeyDownEvent;
    /** Handle keyup on tabs */
    private _handleKeyUpEvent;
    private _activateTab;
    /** @internal */
    render(): JSX.Element;
}
export {};
//# sourceMappingURL=Tabs.d.ts.map