"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Text
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FilteredText = void 0;
// cSpell:ignore focusvalue
const React = require("react");
const classnames = require("classnames");
require("./FilteredText.scss");
/** Component used to highlight filter matches within a text string.
 * @alpha
 */
function FilteredText(props) {
    const { value, className, matches, matchClassName, matchStyle } = props, otherProps = __rest(props, ["value", "className", "matches", "matchClassName", "matchStyle"]);
    // istanbul ignore else
    if (matches && matches.length > 0) {
        const spans = [];
        let startPos = 0;
        for (const span of matches) {
            // istanbul ignore else
            if (span.start !== startPos)
                spans.push(React.createElement("span", { key: startPos, className: "uicore-partial-filtered-text" }, value.substr(startPos, span.start - startPos)));
            spans.push(React.createElement("span", { key: span.start, style: matchStyle, className: classnames("uicore-filtered-text-match", matchClassName) }, value.substr(span.start, span.end - span.start)));
            startPos = span.end;
        }
        const endPos = value.length;
        // istanbul ignore else
        if (startPos < endPos) {
            spans.push(React.createElement("span", { key: startPos, className: "uicore-partial-filtered-text" }, value.substr(startPos, endPos - startPos)));
        }
        return React.createElement("div", Object.assign({}, otherProps, { className: classnames("uicore-filtered-text", className), title: value }), spans);
    }
    return React.createElement("span", Object.assign({}, otherProps, { className: classnames("uicore-filtered-text", className), title: value }), value);
}
exports.FilteredText = FilteredText;
//# sourceMappingURL=FilteredText.js.map