"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Tiles
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Tile = void 0;
const classnames = require("classnames");
const React = require("react");
const IconComponent_1 = require("../icons/IconComponent");
/** The Tile React component is a container for rendering elements that can be grouped together.
 * @beta
 */
class Tile extends React.Component {
    /** @internal */
    render() {
        const stepType = (this.props.stepCount && this.props.stepCount < 13)
            ? Math.floor(this.props.stepNum * 12 / (this.props.stepCount - 1))
            : this.props.stepNum % 16;
        const stepClass = `uicore-step-${stepType}`;
        const classNames = classnames("uicore-tiles-tile", stepClass, this.props.featured && "uicore-featured", this.props.minimal && "uicore-minimal");
        const icon = (typeof this.props.icon === "string") ? React.createElement(IconComponent_1.Icon, { iconSpec: this.props.icon }) : this.props.icon;
        return (React.createElement("div", { className: classNames, style: this.props.style },
            React.createElement("a", { className: "uicore-link", href: this.props.href, onClick: this.props.onClick },
                React.createElement("div", { className: "uicore-icon" }, icon),
                React.createElement("p", { className: "uicore-title" }, this.props.title)),
            this.props.children && !this.props.minimal &&
                React.createElement("div", { className: "uicore-children" }, this.props.children)));
    }
}
exports.Tile = Tile;
/** @internal */
Tile.defaultProps = {
    stepNum: 0,
};
//# sourceMappingURL=Tile.js.map