/** @packageDocumentation
 * @module Toggle
 */
import "./Toggle.scss";
import * as React from "react";
import { CommonProps } from "../utils/Props";
/** Toggle display types
 * @public
 */
export declare enum ToggleButtonType {
    /** Primary (green) background */
    Primary = 0,
    /** Blue background */
    Blue = 1
}
/** Properties for [[Toggle]] component
 * @public
 */
export interface ToggleProps extends CommonProps {
    /** Indicates whether the Toggle is disabled (default is false) */
    disabled?: boolean;
    /** Indicates whether the Toggle is "on" or "off" (default is false) */
    isOn?: boolean;
    /** Show the toggle rounded or square (rounded is default) */
    rounded?: boolean;
    /** Show a check mark icon when the toggle is "on" (false is default) */
    showCheckmark?: boolean;
    /** Button type, either Primary or Blue (Blue is default) */
    buttonType?: ToggleButtonType;
    /** Function called when the toggle state is changed */
    onChange?: (checked: boolean) => any;
    /** Function called when the toggle loses focus  */
    onBlur?: (event: React.FocusEvent) => any;
    /** Use larger size (default is false) */
    large?: boolean;
    /** Indicates whether to set focus to the input element */
    setFocus?: boolean;
    /** Tooltip text */
    title?: string;
    /** Provides ability to return reference to HTMLInputElement */
    ref?: React.Ref<HTMLInputElement>;
}
/**
 * Toggle React component to show an "on" or "off" state
 * @public
 */
export declare const Toggle: (props: ToggleProps) => JSX.Element | null;
//# sourceMappingURL=Toggle.d.ts.map