/** @packageDocumentation
 * @module Tooltip
 */
import "./Tooltip.scss";
import * as React from "react";
import { CommonProps } from "../utils/Props";
import { RelativePosition } from "@bentley/ui-abstract";
/** Available tooltip placements.
 * @beta
 */
export declare type TooltipPlacement = "bottom" | "left" | "right" | "top";
/** Properties for the [[Tooltip]] component
 * @beta
 */
export interface TooltipProps extends CommonProps {
    /** Tooltip content. */
    children?: React.ReactNode;
    /** Target element of a tooltip. */
    target?: HTMLElement;
    /** Allows to control tooltip visibility state. */
    visible?: boolean;
    /** Preferred tooltip placement. Defaults to `top`. */
    placement?: TooltipPlacement;
}
/** Component that displays tooltip for a specified target element.
 * @beta
 */
export declare function Tooltip(props: TooltipProps): JSX.Element;
/** @internal */
export declare function placementToPosition(placement: TooltipPlacement | undefined): RelativePosition;
//# sourceMappingURL=Tooltip.d.ts.map