"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Tooltip
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.placementToPosition = exports.Tooltip = void 0;
require("./Tooltip.scss");
const classnames = require("classnames");
const React = require("react");
const Popup_1 = require("../popup/Popup");
const ui_abstract_1 = require("@bentley/ui-abstract");
/** Component that displays tooltip for a specified target element.
 * @beta
 */
function Tooltip(props) {
    const { visible, target, placement } = props;
    const [open, setOpen] = React.useState(false);
    React.useEffect(() => {
        const mouseenter = () => {
            setOpen(true);
        };
        const mouseleave = () => {
            setOpen(false);
        };
        visible === undefined && target && target.addEventListener("mouseenter", mouseenter);
        visible === undefined && target && target.addEventListener("mouseleave", mouseleave);
        return () => {
            visible === undefined && target && target.removeEventListener("mouseenter", mouseenter);
            visible === undefined && target && target.removeEventListener("mouseleave", mouseleave);
        };
    }, [visible, target]);
    const className = classnames("core-tooltip-tooltip", props.className);
    return (React.createElement(Popup_1.Popup, { className: className, isOpen: props.visible === undefined ? open : props.visible, position: placementToPosition(placement), showShadow: false, target: target }, props.children));
}
exports.Tooltip = Tooltip;
/** @internal */
function placementToPosition(placement) {
    switch (placement) {
        case "bottom":
            return ui_abstract_1.RelativePosition.Bottom;
        case "left":
            return ui_abstract_1.RelativePosition.Left;
        case "right":
            return ui_abstract_1.RelativePosition.Right;
        case undefined:
        case "top":
            return ui_abstract_1.RelativePosition.Top;
    }
}
exports.placementToPosition = placementToPosition;
//# sourceMappingURL=Tooltip.js.map