"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Tree
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.TreeNodePlaceholder = void 0;
require("./Placeholder.scss");
const classnames = require("classnames");
const React = require("react");
const Node_1 = require("./Node");
/**
 * Presentation React component for a placeholder to be displayed instead of a node while it's being loaded
 * @public
 */
class TreeNodePlaceholder extends React.PureComponent {
    render() {
        const className = classnames("core-tree-placeholder", this.props.className);
        const offset = this.props.level * Node_1.LEVEL_OFFSET;
        const min = (this.props.minWidth || 50);
        const max = (this.props.maxWidth || 200);
        const width = Math.floor(min + Math.random() * (max - min));
        const style = Object.assign(Object.assign({}, this.props.style), { paddingLeft: `${offset}px` });
        return (React.createElement("div", { className: className, style: style, "data-testid": this.props["data-testid"] },
            React.createElement("div", { className: "contents", style: { width: `${width}px` } })));
    }
}
exports.TreeNodePlaceholder = TreeNodePlaceholder;
//# sourceMappingURL=Placeholder.js.map