"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module UiSettings
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.LocalUiSettings = exports.LocalSettingsStorage = void 0;
const UiSettingsStorage_1 = require("./UiSettingsStorage");
/**
 * Implementation of [[UiSettingsStorage]] using Window.localStorage.
 * @public
 */
class LocalSettingsStorage {
    constructor(w = window) {
        this.w = w;
    }
    async getSetting(settingNamespace, settingName) {
        const setting = this.w.localStorage.getItem(`${settingNamespace}.${settingName}`);
        if (setting !== null)
            return { status: UiSettingsStorage_1.UiSettingsStatus.Success, setting: JSON.parse(setting) };
        else
            return { status: UiSettingsStorage_1.UiSettingsStatus.NotFound };
    }
    async saveSetting(settingNamespace, settingName, setting) {
        this.w.localStorage.setItem(`${settingNamespace}.${settingName}`, JSON.stringify(setting));
        return { status: UiSettingsStorage_1.UiSettingsStatus.Success };
    }
    async deleteSetting(settingNamespace, settingName) {
        const name = `${settingNamespace}.${settingName}`;
        const setting = this.w.localStorage.getItem(name);
        if (setting === null)
            return { status: UiSettingsStorage_1.UiSettingsStatus.NotFound };
        this.w.localStorage.removeItem(name);
        return { status: UiSettingsStorage_1.UiSettingsStatus.Success };
    }
}
exports.LocalSettingsStorage = LocalSettingsStorage;
/** Alias for [[LocalSettingsStorage]]
 * @beta @deprecated use LocalSettingsStorage
 */
class LocalUiSettings extends LocalSettingsStorage {
    constructor(w = window) { super(w); }
}
exports.LocalUiSettings = LocalUiSettings;
//# sourceMappingURL=LocalSettingsStorage.js.map