"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module UiSettings
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.SessionUiSettings = exports.SessionSettingsStorage = void 0;
const UiSettingsStorage_1 = require("./UiSettingsStorage");
/**
 * Implementation of [[UiSettings]] using Window.sessionStorage.
 * @public
 */
class SessionSettingsStorage {
    constructor(w = window) {
        this.w = w;
    }
    async getSetting(settingNamespace, settingName) {
        const setting = this.w.sessionStorage.getItem(`${settingNamespace}.${settingName}`);
        if (setting !== null)
            return { status: UiSettingsStorage_1.UiSettingsStatus.Success, setting: JSON.parse(setting) };
        else
            return { status: UiSettingsStorage_1.UiSettingsStatus.NotFound };
    }
    async saveSetting(settingNamespace, settingName, setting) {
        this.w.sessionStorage.setItem(`${settingNamespace}.${settingName}`, JSON.stringify(setting));
        return { status: UiSettingsStorage_1.UiSettingsStatus.Success };
    }
    async deleteSetting(settingNamespace, settingName) {
        const name = `${settingNamespace}.${settingName}`;
        const setting = this.w.sessionStorage.getItem(name);
        if (setting === null)
            return { status: UiSettingsStorage_1.UiSettingsStatus.NotFound };
        this.w.sessionStorage.removeItem(name);
        return { status: UiSettingsStorage_1.UiSettingsStatus.Success };
    }
}
exports.SessionSettingsStorage = SessionSettingsStorage;
/** Alias for [[SessionSettingsStorage]]
 * @beta @deprecated use SessionSettingsStorage
 */
class SessionUiSettings extends SessionSettingsStorage {
    constructor(w = window) { super(w); }
}
exports.SessionUiSettings = SessionUiSettings;
//# sourceMappingURL=SessionSettingsStorage.js.map