/** @packageDocumentation
 * @module UiSettings
 */
import { UiSettingsResult, UiSettingsStorage } from "./UiSettingsStorage";
/** A Ui Setting with namespace and setting name.
 * @public
 */
export declare class UiSetting<T> {
    settingNamespace: string;
    settingName: string;
    getValue: () => T;
    applyValue?: ((v: T) => void) | undefined;
    defaultValue?: T | undefined;
    /** Constructor
     * @param settingNamespace  Namespace for the setting, passed to UiSettings.
     * @param settingName       Name for the setting, passed to UiSettings.
     * @param getValue          Function for getting the value from the application.
     * @param applyValue        Function for applying the setting value to the application.
     * @param defaultValue      Optional default value if not already stored.
     */
    constructor(settingNamespace: string, settingName: string, getValue: () => T, applyValue?: ((v: T) => void) | undefined, defaultValue?: T | undefined);
    /** Gets the setting from [[UiSettingsStorage]] */
    getSetting(storage: UiSettingsStorage): Promise<UiSettingsResult>;
    /** Saves the setting value from the `getValue` function to UiSettings */
    saveSetting(storage: UiSettingsStorage): Promise<UiSettingsResult>;
    /** Deletes the setting from UiSettings */
    deleteSetting(storage: UiSettingsStorage): Promise<UiSettingsResult>;
    /** Gets the setting from UiSettings and applies the value using the `applyValue` function */
    getSettingAndApplyValue(storage: UiSettingsStorage): Promise<UiSettingsResult>;
}
//# sourceMappingURL=UiSetting.d.ts.map