/** @packageDocumentation
 * @module Utilities
 */
/** Describes 2d points.
 * @public
 */
export interface PointProps {
    readonly x: number;
    readonly y: number;
}
/** Describes and provides methods to work with 2d points.
 * @internal
 */
export declare class Point implements PointProps {
    readonly x: number;
    readonly y: number;
    /** Creates point from [[PointProps]]. */
    static create(pointProps: PointProps): Point;
    /** Creates a new point. */
    constructor(x?: number, y?: number);
    /** Calculates Euclidean distance to other point. */
    getDistanceTo(other: PointProps): number;
    /** Calculates grid-like distance to other point. */
    getManhattanDistanceTo(other: PointProps): number;
    /** Gets offset to other point. */
    getOffsetTo(other: PointProps): Point;
    /** @returns New [[Point]] that is offset along the X and Y axes. */
    offset(offset: PointProps): Point;
    /** @returns New [[Point]] that is offset along the X axis. */
    offsetX(offset: number): Point;
    /** @returns New [[Point]] that is offset along the Y axis. */
    offsetY(offset: number): Point;
    /** @returns True if position of this and other points are equal. */
    equals(other: PointProps): boolean;
    /** @returns New [[Point]] with modified x value. */
    setX(x: number): Point;
    /** @returns New [[Point]] with modified y value. */
    setY(y: number): Point;
    /** @returns New [[Point]] with coordinates multiplied by specified factor. */
    multiply(factor: number): Point;
    /** @returns [[PointProps]] object for this point. */
    toProps(): PointProps;
}
//# sourceMappingURL=Point.d.ts.map