"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ScrollPositionMaintainer = void 0;
/**
 * A helper class to recursively save and restore scroll positions.
 * Usage:
 * ```ts
 * // scroll positions are saved when `ScrollPositionMaintainer` object is created
 * const maintainer = new ScrollPositionMaintainer(element);
 * // can do something with `element` here
 * // disposing the `maintainer` object restores scroll positions
 * maintainer.dispose();
 * ```
 * @beta
 */
class ScrollPositionMaintainer {
    constructor(el) {
        this._storage = new Map();
        ScrollPositionMaintainer.saveScrollPositions([el], this._storage);
    }
    dispose() { ScrollPositionMaintainer.restoreScrollPositions(this._storage); }
    static saveScrollPositions(elems, storage) {
        for (const el of elems) {
            // istanbul ignore else
            if (el.scrollTop)
                storage.set(el, el.scrollTop);
            // istanbul ignore else
            if (el.children)
                this.saveScrollPositions(el.children, storage);
        }
    }
    static restoreScrollPositions(storage) {
        storage.forEach((scrollTop, el) => el.scrollTop = scrollTop);
    }
}
exports.ScrollPositionMaintainer = ScrollPositionMaintainer;
//# sourceMappingURL=ScrollPositionMaintainer.js.map