/** @packageDocumentation
 * @module Utilities
 */
/** Signature for [[Timer]] execute callback.
 * @public
 */
export declare type ExecuteHandler = (this: void) => void;
/** Notifies handler after a set interval.
 * @public
 */
export declare class Timer {
    private _delay;
    private _isRunning;
    private _timerId;
    private _onExecute;
    /**
     * Creates a new Timer.
     * @param msDelay Time interval in milliseconds after which handler will be notified.
     */
    constructor(msDelay: number);
    /** Indicates whether the timer is running */
    get isRunning(): boolean;
    /** Time interval in milliseconds after which handler will be notified. */
    get delay(): number;
    set delay(ms: number);
    /** Set handler that is called after a set interval. */
    setOnExecute(onExecute: ExecuteHandler | undefined): void;
    /** Starts this Timer. */
    start(): void;
    /** Stops this Timer. */
    stop(): void;
    private execute;
    private setTimeout;
    private clearTimeout;
}
//# sourceMappingURL=Timer.d.ts.map