"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Utilities
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Timer = void 0;
/** Notifies handler after a set interval.
 * @public
 */
class Timer {
    /**
     * Creates a new Timer.
     * @param msDelay Time interval in milliseconds after which handler will be notified.
     */
    constructor(msDelay) {
        this._isRunning = false;
        this._timerId = 0;
        this._delay = msDelay;
    }
    /** Indicates whether the timer is running */
    get isRunning() {
        return this._isRunning;
    }
    /** Time interval in milliseconds after which handler will be notified. */
    get delay() {
        return this._delay;
    }
    set delay(ms) {
        this._delay = ms;
    }
    /** Set handler that is called after a set interval. */
    setOnExecute(onExecute) {
        this._onExecute = onExecute;
    }
    /** Starts this Timer. */
    start() {
        if (this._isRunning)
            this.clearTimeout();
        this._isRunning = true;
        this.setTimeout();
    }
    /** Stops this Timer. */
    stop() {
        if (!this._isRunning)
            return;
        this._isRunning = false;
        this.clearTimeout();
    }
    execute() {
        this._onExecute && this._onExecute();
        this._isRunning = false;
    }
    setTimeout() {
        this._timerId = window.setTimeout(() => this.execute(), this._delay);
    }
    clearTimeout() {
        window.clearTimeout(this._timerId);
    }
}
exports.Timer = Timer;
//# sourceMappingURL=Timer.js.map