"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Utilities
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.useEffectSkipFirst = void 0;
const react_1 = require("react");
/**
 * Custom hook which works like useEffect hook, but does not invoke callback when effect is triggered for the first time.
 * @public
 */
function useEffectSkipFirst(callback, deps) {
    const skipFirst = react_1.useRef(true);
    react_1.useEffect(() => {
        if (skipFirst.current) {
            skipFirst.current = false;
            return;
        }
        return callback();
    }, deps); // eslint-disable-line react-hooks/exhaustive-deps
}
exports.useEffectSkipFirst = useEffectSkipFirst;
//# sourceMappingURL=useEffectSkipFirst.js.map