"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useLifecycleLogging = void 0;
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
const react_1 = require("react");
/**
 * Logs to console information about component lifecycle: mounting, re-rendering and unmounting.
 * @internal
 */
function useLifecycleLogging(name, props, context) {
    react_1.useEffect(() => {
        // eslint-disable-next-line no-console
        console.log(`[useLifecycleLogging]: '${name}' Component mounted.`);
        return () => {
            // eslint-disable-next-line no-console
            console.log(`[useLifecycleLogging]: '${name}' Component unmounted.`);
        };
    }, []); // eslint-disable-line react-hooks/exhaustive-deps
    const prevProps = react_1.useRef(props);
    const prevContext = react_1.useRef(context);
    const firstRun = react_1.useRef(true);
    react_1.useEffect(() => {
        if (firstRun.current) {
            firstRun.current = false;
            return;
        }
        function getDiff(prev, current) {
            const diff = {};
            for (const key of Object.keys(current)) {
                if (prev[key] !== current[key]) {
                    diff[key] = {
                        from: prev[key],
                        to: current[key],
                    };
                }
            }
            return diff;
        }
        const propsDiff = getDiff(prevProps.current, props);
        const contextDiff = { from: context === undefined ? context : prevContext.current, to: context };
        if (Object.keys(propsDiff).length > 0 && prevContext.current !== context) {
            // eslint-disable-next-line no-console
            console.log(`[useLifecycleLogging]: '${name}' Props and context changed: `, propsDiff, contextDiff);
        }
        else if (Object.keys(propsDiff).length > 0) {
            // eslint-disable-next-line no-console
            console.log(`[useLifecycleLogging]: '${name}' Props changed: `, propsDiff);
        }
        else if (prevContext.current !== context) {
            // eslint-disable-next-line no-console
            console.log(`[useLifecycleLogging]: '${name}' Context changed: `, contextDiff);
        }
        else {
            // eslint-disable-next-line no-console
            console.log(`[useLifecycleLogging]: '${name}' Component re-rendered.`);
        }
        prevProps.current = props;
        prevContext.current = context;
    });
}
exports.useLifecycleLogging = useLifecycleLogging;
//# sourceMappingURL=useLifecycleLogging.js.map