/** @packageDocumentation
 * @module Utilities
 */
import * as React from "react";
/** @internal */
export declare class WidgetElementSet extends Set<React.RefObject<Element>> {
}
/** Returns the proximity scale associated with the shortest distance from the element(s) to the mouse.
 * @internal
 */
export declare const useProximityToMouse: (elementSet: WidgetElementSet, snap?: boolean, threshold?: number) => number;
/** Default proximity threshold.
 * @internal
 */
export declare const PROXIMITY_THRESHOLD_DEFAULT = 100;
/** Default toolbar opacity.
 * @internal
 */
export declare const TOOLBAR_OPACITY_DEFAULT = 0.5;
/** Default toolbar box-shadow opacity.
 * @internal
 */
export declare const TOOLBAR_BOX_SHADOW_OPACITY_DEFAULT = 0.35;
/** Default toolbar backdrop-filter blur.
 * @internal
 */
export declare const TOOLBAR_BACKDROP_FILTER_BLUR_DEFAULT = 10;
/** Calculates a proximity scale for further calculations given the proximity and threshold.
 * @internal
 */
export declare const calculateProximityScale: (proximity: number, snap?: boolean, threshold?: number) => number;
/** Calculates a toolbar opacity based on a given proximity scale.
 * @internal
 */
export declare const calculateToolbarOpacity: (proximityScale: number) => number;
/** Calculates a box-shadow opacity based on a given proximity scale.
 * @internal
 */
export declare const calculateBoxShadowOpacity: (proximityScale: number) => number;
/** Calculates a backdrop-filter blur based on a given proximity scale.
 * @internal
 */
export declare const calculateBackdropFilterBlur: (proximityScale: number) => number;
/** Gets the Toolbar background-color based on a given opacity.
 * @internal
 */
export declare const getToolbarBackgroundColor: (opacity: number) => string;
/** Gets the Toolbar box-shadow based on a given opacity.
 * @internal
 */
export declare const getToolbarBoxShadow: (opacity: number) => string;
/** Gets the Toolbar backdrop-filter based on a given blur amount.
 * @internal
 */
export declare const getToolbarBackdropFilter: (filterBlur: number) => string;
//# sourceMappingURL=useProximityToMouse.d.ts.map