"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Utilities
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.mergeRefs = exports.useRefs = void 0;
const React = require("react");
/** Callback ref type guard. */
function isRefCallback(ref) {
    return typeof ref === "function";
}
/** Hook used to combine multiple refs.
 * @internal
 */
function useRefs(...refs) {
    return React.useCallback((instance) => {
        for (const ref of refs) {
            // istanbul ignore else
            if (ref) {
                if (isRefCallback(ref)) {
                    ref(instance);
                }
                else {
                    ref.current = instance;
                }
            }
        }
    }, [...refs]); // eslint-disable-line react-hooks/exhaustive-deps
}
exports.useRefs = useRefs;
/** Used to combine multiple refs for a class component.
 * @internal
 */
function mergeRefs(...refs) {
    return ((instance) => {
        for (const ref of refs) {
            // istanbul ignore else
            if (ref) {
                if (isRefCallback(ref)) {
                    ref(instance);
                }
                else {
                    ref.current = instance;
                }
            }
        }
    });
}
exports.mergeRefs = mergeRefs;
//# sourceMappingURL=useRefs.js.map