"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Utilities
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.useTargeted = void 0;
const React = require("react");
/** Returns a stateful value that indicates if the component is targeted/hovered.
 * @internal
 */
const useTargeted = (ref) => {
    const [targeted, setTargeted] = React.useState(false);
    React.useEffect(() => {
        const handleDocumentPointerMove = (e) => {
            setTargeted(!!ref.current && !!e.target && (e.target instanceof Node) && ref.current.contains(e.target));
        };
        document.addEventListener("pointermove", handleDocumentPointerMove);
        return () => {
            document.removeEventListener("pointermove", handleDocumentPointerMove);
        };
    }, [ref]);
    return targeted;
};
exports.useTargeted = useTargeted;
//# sourceMappingURL=useTargeted.js.map